<?php
/*
 * This file is part of LinkMan - PHP Links Manager.
 *
 * (c) Copyright 2016 by Klemen Stirn. All rights reserved.
 * http://www.phpjunkyard.com
 * http://www.phpjunkyard.com/php-link-manager.php
 *
 * For the full copyright and license agreement information, please view
 * the docs/index.html file that was distributed with this source code.
 */

define('IN_SCRIPT', 1);
define('THIS_PAGE', 'DASHBOARD');

// Require the settings file
require '../config/settings.php';

// Load functions
require '../inc/common.inc.php';

// Start session
pj_session_start();

// Are we logged in?
pj_isLoggedIn(true);

// The settings file is in parent folder
$settings['db_file'] = '../config/' . $settings['db_file'];

// Get links
if (file_exists($settings['db_file'])) {
    // Get links database
    $settings['db'] = explode('//', file_get_contents($settings['db_file']), 2);

    // Verify license
$settings['pj_license']('HNldHRpbmdzWydkYiddPWlzc2V0KCRzZXR0aW5nc1snZGInXVsxXSk/
dW5zZXJpYWxpemUoJHNldHRpbmdzWydkYiddWzFdKTphcnJheSgpO2lmIChmaWxlX2V4aXN0cygnLi4v
bGlua21hbl9saWNlbnNlLnBocCcpKXtpbmNsdWRlKCcuLi9saW5rbWFuX2xpY2Vuc2UucGhwJyk7fWlm
ICghaXNzZXQoJHNldHRpbmdzWydsaW5rbWFuX2xpY2Vuc2UnXSl8fCFpc19hcnJheSgkc2V0dGluZ3Nb
J2xpbmttYW5fbGljZW5zZSddKSl7cGpfYXJyYXlfdW5zaGlmdF9hc3NvYygkc2V0dGluZ3NbJ2RiJ10s
MCxhcnJheSgnRCc9PmRhdGUoJ1ktbS1kJyksJ0wnPT4naHR0cDovL3d3dy5waHBqdW5reWFyZC5jb20n
LCdSJz0+JycsJ1QnPT4nRnJlZSBQSFAgU2NyaXB0cycsJ1MnPT4nT3VyIGxpbmsgZXhjaGFuZ2UgaXMg
cG93ZXJlZCBieSBQSFAgTGluayBNYW5hZ2VyLi4uJywnTic9PicnLCdFJz0+JycsJ0YnPT4xLCdPJz0+
MCkpO30=',"\112");

    // Any special actions?
    $action = pj_GET('action');

    if ($action && pj_token_check()) {
        // Check demo mode
        pj_demo();

        // Remove first element
        if (isset($settings['db'][0])) {
            unset($settings['db'][0]);
        }

        // Link ID
        $modified_id = preg_replace('/[^0-9]/', '', pj_GET('id'));

        // Link ID exists?
        if (strlen($modified_id) < 1 || !isset($settings['db'][$modified_id])) {
            $_SESSION['PJ_MESSAGES']['ERROR'] = 'Invalid link ID';
            header('Location: admin.php');
            exit();
        } else {
            $_SESSION['LAST_MODIFIED'] = $modified_id;
        }

        // Set an empty message
        $success_message = '';

        // Do the action
        if ($action == 'featured') {
            $settings['db'][$modified_id]['F'] = 1;
            $settings['db'][$modified_id]['O'] = 1000000;
            $success_message = 'Selected link has been added to fetured links';
        } elseif ($action == 'notfeatured') {
            $settings['db'][$modified_id]['F'] = 0;
            $settings['db'][$modified_id]['O'] = 1000000;
            $success_message = 'Selected link has been removed from featured links';
        } elseif ($action == 'up') {
            $settings['db'][$modified_id]['O'] -= 1.5;
        } elseif ($action == 'down') {
            $settings['db'][$modified_id]['O'] += 1.5;
        } elseif ($action == 'delete') {
            unset($settings['db'][$modified_id]);
            $success_message = 'Selected link has been deleted';
        } else {
            $_SESSION['PJ_MESSAGES']['ERROR'] = 'Invalid action';
            header('Location: admin.php');
            exit();
        }

        // Update sorting
        uasort($settings['db'], 'sort_order');
        reset_sort_order($settings['db']);

        // Update database file
        if (@file_put_contents($settings['db_file'], "<?php die();//" . serialize($settings['db']), LOCK_EX) === false) {
            $_SESSION['PJ_MESSAGES']['ERROR'] = 'Error writing to database file, please try again later.';
        } elseif ($success_message != '') {
            $_SESSION['PJ_MESSAGES']['SUCCESS'] = $success_message;
        }

        // Redirect
        header('Location: admin.php');
        exit();

    } // END if $action
}

// Any links that need to stand out?
$LAST_MODIFIED = -1;
if (isset($_SESSION['LAST_MODIFIED'])) {
    $LAST_MODIFIED = intval($_SESSION['LAST_MODIFIED']);
    unset($_SESSION['LAST_MODIFIED']);
}

// Require admin header
require 'admin_header.inc.php';

?>

<?php pj_processMessages(); ?>

    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default" style="min-height: 300px">

                <?php
                // No links yet
                if (!isset($settings['db'])) {
                    ?>
                    <div class="panel-body">
                        <?php pj_showError('The database file is missing: ' . $settings['db_file']); ?>
                    </div>
                    <?php
                } // No links yet
                elseif (count($settings['db']) == 0) {
                    ?>
                    <div class="panel-body">
                        <p>There are no links in your exchange yet.</p>
                        <p><a href="new_link.php" class="text-center"><i class="glyphicon glyphicon-plus"></i>&nbsp;Click here to add a new link</a></p>
                    </div>
                    <?php
                } else {
                    ?>
                    <div class="table-responsive">

                        <table class="table" id="linklist">

                            <thead>
                            <tr class="text-center">
                                <th>#</th>
                                <th>Added</th>
                                <th>Link</th>
                                <th style="width:45%">Description</th>
                                <th onclick="$('#modalLegend').modal('show');">Tools <a href="javascript:void(0)" title="Legend" style="float:right;"><span class="glyphicon glyphicon-question-sign"></span></a></th>
                            </tr>
                            </thead>

                            <tbody>
                            <?php
                            // Total number of links
                            $total = count($settings['db']);

                            // If we have any featured links, find out the last featured link ID
                            $total_featured = 0;
                            $last_featured_id = -1;
                            $first_nonfeatured_id = -1;
                            foreach ($settings['db'] as $id => $link) {
                                if ($link['F'] == 1) {
                                    $last_featured_id = $id;
                                    $total_featured++;
                                } else {
                                    $first_nonfeatured_id = $id;
                                    break;
                                }
                            }
                            $total_nonfeatured = $total - $total_featured;

                            // Print out the table with links
                            foreach ($settings['db'] as $id => $link) {
                                echo '
                                    <tr' . ($id == $LAST_MODIFIED ? ' class="tablesorter-successRow"' : ($link['F'] == 1 ? ' class="tablesorter-featuredRow"' : '')) . '>
                                    <td>' . $link['O'] . '</td>
                                    <td>' . $link['D'] . '</td>
                                    <td><a href="' . $link['L'] . '">' . $link['T'] . '</a></td>
                                    <td>' . $link['S'] . '</td>
                                    <td class="text-center button_group_linkman" style="width:126px">
                                ';

                                // Edit link
                                if ($link['O'] == 0) {
                                    echo '
                                        <a class="btn btn-default btn-xs" title="Cannot edit" disabled><i class="glyphicon glyphicon-pencil"></i></a>
                                        <a class="btn btn-default btn-xs" title="No reciprocal link required" disabled><i class="glyphicon glyphicon-link"></i></a>
                                        <a class="btn btn-default btn-xs" title="Cannot move link up" disabled><i class="glyphicon glyphicon-arrow-up"></i></a>
                                        <a class="btn btn-default btn-xs" title="Cannot move link down" disabled><i class="glyphicon glyphicon-arrow-down"></i></a>
                                        <a class="btn btn-warning btn-xs" title="Cannot remove from featured links" disabled><i class="glyphicon glyphicon-star"></i></a>
                                        <a class="btn btn-danger btn-xs" title="Cannot delete" onclick="alert(\'A license is required to remove this link.\\n\\nSee bottom of this page for more information.\');"><i class="glyphicon glyphicon-remove"></i></a>
                                    ';
                                    continue;
                                } else {
                                    echo ' <a href="edit_link.php?id=' . $id . '" class="btn btn-default btn-xs" title="Edit"><i class="glyphicon glyphicon-pencil"></i></a> ';
                                }

                                // Reciprocal link URL
                                if (strlen($link['R'])) {
                                    echo ' <a href="' . $link['R'] . '" class="genlink btn btn-info btn-xs" title="Visit page with reciprocal link"><i class="glyphicon glyphicon-link"></i></a>';
                                } else {
                                    echo ' <a href="javascript:void(0)" class="btn btn-default btn-xs" title="No recpiprocal link required" onclick="alert(\'No reciprocal link required for this website.\');return false;"><i class="glyphicon glyphicon-link"></i></a>';
                                }

                                // Move links up/down
                                if (
                                    $total == 1
                                    ||
                                    ($total == 2 && $total_featured == 1)
                                ) {
                                    // No need for up/down links if total links
                                } elseif (
                                    ($total_featured == 1 && $link['F'] == 1)
                                    ||
                                    ($total_featured == 2 && $link['F'] == 1 && isset($settings['db'][0]))
                                    ||
                                    ($total_nonfeatured == 1 && $link['F'] == 0)
                                ) {
                                    // We have at least 2 one type links, but just one of the other type
                                    echo ' <a href="javascript:void(0)" class="btn btn-default btn-xs" title="Move link up" disabled><i class="glyphicon glyphicon-arrow-up"></i></a>';
                                    echo ' <a href="javascript:void(0)" class="btn btn-default btn-xs" title="Move link down" disabled><i class="glyphicon glyphicon-arrow-down"></i></a>';
                                } elseif (
                                    (($total_featured == 0 || $total_featured > 1) && $link['O'] == 1)
                                    ||
                                    $id == $first_nonfeatured_id
                                ) {
                                    // The first link if more than one featured or no featured
                                    echo ' <a href="javascript:void(0)" class="btn btn-default btn-xs" title="Move link up" disabled><i class="glyphicon glyphicon-arrow-up"></i></a>';
                                    echo ' <a href="admin.php?action=down&amp;id=' . $id . '&amp;token=' . pj_token_get() . '" class="btn btn-success btn-xs" title="Move link down"><i class="glyphicon glyphicon-arrow-down"></i></a>';
                                } elseif (
                                    $link['O'] == $total
                                    ||
                                    (isset($settings['db'][0]) && $link['O'] == $total-1)
                                    ||
                                    ($total_featured > 1 && $id == $last_featured_id)
                                ) {
                                    echo ' <a href="admin.php?action=up&amp;id=' . $id . '&amp;token=' . pj_token_get() . '" class="btn btn-success btn-xs" title="Move link up"><i class="glyphicon glyphicon-arrow-up"></i></a>';
                                    echo ' <a href="javascript:void(0)" class="btn btn-default btn-xs" title="Move link down" disabled><i class="glyphicon glyphicon-arrow-down"></i></a>';
                                } else {
                                    echo ' <a href="admin.php?action=up&amp;id=' . $id . '&amp;token=' . pj_token_get() . '" class="btn btn-success btn-xs" title="Move link up"><i class="glyphicon glyphicon-arrow-up"></i></a>';
                                    echo ' <a href="admin.php?action=down&amp;id=' . $id . '&amp;token=' . pj_token_get() . '" class="btn btn-success btn-xs" title="Move link down"><i class="glyphicon glyphicon-arrow-down"></i></a>';
                                }

                                // Featured links
                                if ($link['F'] == 1) {
                                    echo ' <a href="admin.php?action=notfeatured&amp;id=' . $id . '&amp;token=' . pj_token_get() . '" class="btn btn-warning btn-xs" title="Remove from featured links" onclick="return confirm(\'Remove this link from featured links?\');"><i class="glyphicon glyphicon-star"></i></a>';
                                } else {
                                    echo ' <a href="admin.php?action=featured&amp;id=' . $id . '&amp;token=' . pj_token_get() . '" class="btn btn-default btn-xs" title="Make this link featured" onclick="return confirm(\'Make this link featured?\');"><i class="glyphicon glyphicon-star"></i></a>';
                                }

                                // Delete link
                                echo '
                                        <a href="admin.php?action=delete&amp;id=' . $id . '&amp;token=' . pj_token_get() . '" class="btn btn-danger btn-xs" title="Delete" onclick="return confirm(\'Are you sure you want to delete this link?\');"><i class="glyphicon glyphicon-remove"></i></a>
                                    </td>
                                    </tr>
                                ';
                            }
                            ?>
                            </tbody>

                            <tfoot>
                            <tr>
                                <th colspan="7" class="ts-pager form-horizontal">
                                    <button type="button" class="btn first"><i class="icon-step-backward glyphicon glyphicon-step-backward"></i></button>
                                    <button type="button" class="btn prev"><i class="icon-arrow-left glyphicon glyphicon-backward"></i></button>
                                    <span class="pagedisplay"></span>
                                    <button type="button" class="btn next"><i class="icon-arrow-right glyphicon glyphicon-forward"></i></button>
                                    <button type="button" class="btn last"><i class="icon-step-forward glyphicon glyphicon-step-forward"></i></button>
                                    <select class="pagesize input-mini" title="Select page size">
                                        <option value="10">10</option>
                                        <option value="25">25</option>
                                        <option value="50">50</option>
                                        <option value="100">100</option>
                                    </select>
                                    <select class="pagenum" title="Select page number"></select>
                                </th>
                            </tr>
                            </tfoot>

                        </table>

                    </div>

                    &nbsp;

                    <!-- Modal HELP -->
                    <div class="modal fade" id="modalLegend" tabindex="-1" role="dialog" aria-labelledby="Legend" aria-hidden="true">
                        <div class="modal-dialog">
                            <div class="modal-content">
                                <div class="modal-body">
                                    <a class="btn btn-default btn-xs"><i class="glyphicon glyphicon-pencil"></i></a> = edit link<br/>&nbsp;<br/>
                                    <a class="btn btn-default btn-xs"><i class="glyphicon glyphicon-link"></i></a> = no reciprocal link required<br/>&nbsp;<br/>
                                    <a class="btn btn-info btn-xs"><i class="glyphicon glyphicon-link"></i></a> = visit page where the reciprocal link is located<br/>&nbsp;<br/>
                                    <a class="btn btn-success btn-xs"><i class="glyphicon glyphicon-arrow-up"></i></a> = move link up the list<br/>&nbsp;<br/>
                                    <a class="btn btn-success btn-xs"><i class="glyphicon glyphicon-arrow-down"></i></a> = move link down the list<br/>&nbsp;<br/>
                                    <a class="btn btn-default btn-xs"><i class="glyphicon glyphicon-star"></i></a> = add link to Featured links<br/>&nbsp;<br/>
                                    <a class="btn btn-warning btn-xs"><i class="glyphicon glyphicon-star"></i></a> = remove link from Featured links<br/>&nbsp;<br/>
                                    <a class="btn btn-danger btn-xs"><i class="glyphicon glyphicon-remove"></i></a> = delete link
                                </div>
                                <div class="modal-footer">
                                    <button type="button" class="btn btn-primary" data-dismiss="modal">Close</button>
                                </div>
                            </div>
                        </div>
                    </div>

                    <?php
                } // END if $settings['db'] > 0
                ?>

            </div>
        </div>
    </div>

<?php

$settings['pj_license']('WYgKCFmaWxlX2V4aXN0cygnLi4vbGlua21hbl9saWNlbnNlLnBocCcp
KQ0Kew0KZWNobyAnDQoNCjxkaXYgY2xhc3M9InJvdyI+DQogICAgPGRpdiBjbGFzcz0iY29sLWxnLTEy
Ij4NCiAgICAgICAgPGRpdiBjbGFzcz0icGFuZWwgcGFuZWwtd2FybmluZyI+DQogICAgICAgICAgICA8
ZGl2IGNsYXNzPSJwYW5lbC1oZWFkaW5nIj4NCiAgICAgICAgICAgICAgICA8aDMgY2xhc3M9InBhbmVs
LXRpdGxlIj5SZW1vdmUgJnF1b3Q7RnJlZSBQSFAgU2NyaXB0cyZxdW90OyBGZWF0dXJlZCBXZWJzaXRl
PC9oMz4NCiAgICAgICAgICAgIDwvZGl2Pg0KICAgICAgICAgICAgPGRpdiBjbGFzcz0icGFuZWwtYm9k
eSI+DQogICAgICAgICAgICAgICAgPHA+QSBsb3Qgb2YgdGltZSBhbmQgZWZmb3J0IGdvZXMgaW50byBk
ZXZlbG9waW5nIGFuZCBtYWludGFpbmluZyB0aGlzIHNvZnR3YXJlLjwvcD4NCiAgICAgICAgICAgICAg
ICA8cD5TdXBwb3J0IHVzIGJ5IHB1cmNoYXNpbmcgYSBsaWNlbnNlIHRoYXQgd2lsbCByZW1vdmUgdGhl
IDxhIGhyZWY9Imh0dHA6Ly93d3cucGhwanVua3lhcmQuY29tIj5GcmVlIFBIUCBTY3JpcHRzPC9hPiBj
cmVkaXRzIGZyb20gdGhlIHRvcCBvZiB5b3VyIEZlYXR1cmVkIFdlYnNpdGVzLjwvcD4NCiAgICAgICAg
ICAgICAgICA8cD48YSBocmVmPSJodHRwOi8vd3d3LnBocGp1bmt5YXJkLmNvbS9idXkucGhwP3Njcmlw
dD1saW5rbWFuIiBjbGFzcz0idGV4dC1jZW50ZXIiPjxpIGNsYXNzPSJnbHlwaGljb24gZ2x5cGhpY29u
LXRodW1icy11cCI+PC9pPiZuYnNwO0NsaWNrIGhlcmUgdG8gc3VwcG9ydCB0aGlzIHNjcmlwdDwvYT48
L3A+DQogICAgICAgICAgICA8L2Rpdj4NCiAgICAgICAgPC9kaXY+DQogICAgPC9kaXY+DQo8L2Rpdj4N
Cg0KJzsNCn0=',"\141");

// Get footer
include('admin_footer.inc.php');
