<?php
/*
 * This file is part of LinkMan - PHP Links Manager.
 *
 * (c) Copyright 2016 by Klemen Stirn. All rights reserved.
 * http://www.phpjunkyard.com
 * http://www.phpjunkyard.com/php-link-manager.php
 *
 * For the full copyright and license agreement information, please view
 * the docs/index.html file that was distributed with this source code.
 */

define('IN_SCRIPT', 1);
define('THIS_PAGE', 'BANNED');

// Require the settings file
require '../config/settings.php';

// Load functions
require '../inc/common.inc.php';

// Start session
pj_session_start();

// Are we logged in?
pj_isLoggedIn(true);

// Reasons for banning websites
$settings['ban_reason'] = array(

    0 => 'No reason specified',

    // These will be displayed in the "Ban website" form
    1 => 'Website content against submission terms.',
    2 => 'Website language not accepted.',
    3 => 'Multiple submissions of the same website.',
    4 => 'Multiple websites from the same IP address.',
    5 => 'Excessive advertising.',
    6 => 'Reciprocal link removed.',
    7 => 'Nofollow tag used for reciprocal link.',
    8 => 'Other',

    // Auto-ban
    20 => '(automatically) Website not accessible.',
    21 => '(automatically) Reciprocal links page not accessible.',
    22 => '(automatically) Failed SPAM filter.',
    23 => '(automatically) Fake reciprocal link detected.',
    24 => '(automatically) Link removed after acceptance to exchange.',
    25 => '(automatically) Nofolow tag detected.',

);

$url = '';

// The banned websites database file is in parent folder
$settings['db_file'] = '../config/' . $settings['ban_file'];

// Get links
if (file_exists($settings['db_file'])) {
    // Get links database
    $data = explode('//', file_get_contents($settings['db_file']), 2);

    // Convert contents into an array
    $database = isset($data[1]) ? unserialize($data[1]) : array();
    unset($data);

    // Any POST actions?
    $action = pj_POST('action');

    if ($action && pj_token_check()) {
        // Check demo mode
        if (defined('PJ_DEMO')) {
            die('2');
        }

        // Link URL
        $url = pj_validateURL(pj_POST('url'));

        // Reason
        $reason = intval(pj_POST('reason', -1));

        // Is this a valid reason?
        if (!isset($settings['ban_reason'][$reason])) {
            $reason = 0;
        }

        // Save, if we have an URL
        if (strlen($url)) {
            // Get hostname to add to ban
            $url = get_host_from_url($url);

            // Add (or replace) the database
            $database[$url] = $reason;

            // Update database file
            if (@file_put_contents($settings['db_file'], "<?php die();//" . serialize($database), LOCK_EX) === false) {
                $_SESSION['PJ_MESSAGES']['ERROR'] = 'Error writing to database file, please try again later.';
            } else {
                $_SESSION['PJ_MESSAGES']['SUCCESS'] = 'Website banned!';
            }

            die('1');
        } else {
            die('0');
        }
    }

    // Any GET actions?
    $action = pj_GET('action');

    if ($action && pj_token_check()) {
        // Check demo mode
        pj_demo('banned_websites.php');

        // Banned website
        $website = preg_replace('/[^0-9a-z\.\-]/', '', pj_GET('website'));

        // Banned website exists?
        if (strlen($website) < 1 || !isset($database[$website])) {
            $_SESSION['PJ_MESSAGES']['ERROR'] = 'This is not a banned website';
            header('Location: banned_websites.php');
            exit();
        }

        // Unset the array element
        unset($database[$website]);

        // Update database file
        if (@file_put_contents($settings['db_file'], "<?php die();//" . serialize($database), LOCK_EX) === false) {
            $_SESSION['PJ_MESSAGES']['ERROR'] = 'Error writing to database file, please try again later.';
        } else {
            $_SESSION['PJ_MESSAGES']['SUCCESS'] = 'Website removed from banned websites list.';
        }

        // Redirect
        header('Location: banned_websites.php');
        exit();

    } // END if $action
}

// Require admin header
require 'admin_header.inc.php';

?>

<?php pj_processMessages(); ?>

    <script type="text/javascript">
        $(document).ready(function () {

            $('#banform-alert').hide();

            $('#banformSubmit').click(function (e) {
                e.preventDefault();
                $.post('banned_websites.php', $('#banform').serialize(), function (data, status, xhr) {
                    $('#banform-alert').hide();

                    if (data == "1") {
                        document.location = 'banned_websites.php';
                    }
                    if (data == "2") {
                        alert('This function has been disabled in demo.');
                    }
                    if (data == "0") {
                        $('#url-div').addClass('has-error');
                        $("#banform-alert").text('Error: Please enter a valid website URL.');
                        $('#banform-alert').show();
                    }
                });
            });

        });
    </script>

    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default" style="min-height: 300px">

                <div class="panel-body">
                    <p><button class="btn btn-primary" data-toggle="modal" data-target="#modal"><i class="glyphicon glyphicon-plus"></i>&nbsp;Ban a website</button></p>
                    <p>These websites will not be allowed to join the link exchange. Linkman bans the entire website (sub)domain, not just a specific page.</p>
                </div>

                <?php
                // No links yet
                if (!isset($database)) {
                    ?>
                    <div class="panel-body">
                        <?php pj_showError('The banned websites file is missing: ' . $settings['db_file']); ?>
                    </div>
                    <?php
                } // No links yet
                elseif (count($database) == 0) {
                    ?>
                    <div class="panel-body">
                        <p>No banned websites in the database.</p>
                    </div>
                    <?php
                } else {
                    ?>
                    <div class="table-responsive">

                        <table class="table" id="linklist">

                            <thead>
                            <tr class="text-center">
                                <th>#</th>
                                <th>Link</th>
                                <th>Reason</th>
                                <th class="text-center">Remove</th>
                            </tr>
                            </thead>

                            <tbody>
                            <?php
                            $i = 1;

                            // Print out the table with banned links
                            foreach ($database as $website => $reason) {
                                if (!isset($settings['ban_reason'][$reason])) {
                                    $reason = 0;
                                }

                                echo '
	<tr>
	<td>' . $i . '</td>
	<td><a href="http://' . $website . '">' . $website . '</a></td>
	<td>' . $settings['ban_reason'][$reason] . '</td>
	<td class="text-center button_group_linkman" style="width:126px">
		<a href="banned_websites.php?action=delete&amp;website=' . urlencode($website) . '&amp;token=' . pj_token_get() . '" class="btn btn-danger btn-xs" title="Unban" onclick="return confirm(\'Are you sure you want to remove this website from banned websites?\');"><i class="glyphicon glyphicon-remove"></i></a>
	</td>
	</tr>
	';

                                $i++;
                            }
                            ?>
                            </tbody>

                            <tfoot>
                            <tr>
                                <th colspan="7" class="ts-pager form-horizontal">
                                    <button type="button" class="btn first"><i class="icon-step-backward glyphicon glyphicon-step-backward"></i>
                                    </button>
                                    <button type="button" class="btn prev"><i class="icon-arrow-left glyphicon glyphicon-backward"></i>
                                    </button>
                                    <span class="pagedisplay"></span>
                                    <button type="button" class="btn next"><i class="icon-arrow-right glyphicon glyphicon-forward"></i>
                                    </button>
                                    <button type="button" class="btn last"><i class="icon-step-forward glyphicon glyphicon-step-forward"></i>
                                    </button>
                                    <select class="pagesize input-mini" title="Select page size">
                                        <option value="10">10</option>
                                        <option value="25">25</option>
                                        <option value="50">50</option>
                                        <option value="100">100</option>
                                    </select>
                                    <select class="pagenum" title="Select page number"></select>
                                </th>
                            </tr>
                            </tfoot>

                        </table>

                    </div>

                    <?php
                } // END if $database > 0
                ?>

                &nbsp;

                <!-- Modal NEW BANNED -->
                <div class="modal fade" id="modal" tabindex="-1" role="dialog" aria-labelledby="New_Banned" aria-hidden="true">
                    <div class="modal-dialog">
                        <div class="modal-content">
                            <div class="modal-body">

                                <div id="banform-alert" class="alert alert-danger">Please enter a valid website URL!</div>

                                <form name="banform" id="banform" class="form-horizontal">
                                    <div id="url-div" class="form-group<?php echo isset($error_buffer['url']) ? ' has-error' : ''; ?>">
                                        <label for="url" class="col-lg-3 control-label bold">URL:</label>
                                        <div class="col-lg-9">
                                            <input type="url" id="url" name="url" value="" size="50" class="form-control" placeholder="http://www.example.com">
                                            <p class="help-block"><?php echo isset($error_buffer['url']) ? $error_buffer['url'] : 'URL of the website you wish to ban.'; ?></p>
                                        </div>
                                    </div>
                                    <div class="form-group<?php echo isset($error_buffer['reason']) ? ' has-error' : ''; ?>">
                                        <label for="featured" class="col-lg-3 control-label">Reason:</label>
                                        <div class="col-lg-9">
                                            <select id="reason" name="reason" class="form-control">
                                                <option value="0"> -- Please select --</option>
                                                <?php
                                                foreach ($settings['ban_reason'] as $i => $reason) {
                                                    if ($i > 0 && $i < 20) {
                                                        echo '<option value="' . $i . '">' . $reason . '</option>';
                                                    }
                                                }
                                                ?>
                                            </select>
                                            <p class="help-block"><?php echo isset($error_buffer['reason']) ? $error_buffer['reason'] : 'Reason why you are banning this website.'; ?></p>
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <div class="col-lg-offset-3 col-lg-9">
                                            <input type="hidden" name="action" value="add">
                                            <input type="hidden" name="token" value="<?php echo pj_token_get(); ?>">
                                            <button type="submit" id="banformSubmit" class="btn btn-primary"><i class="glyphicon glyphicon-plus"></i>&nbsp;Ban website</button>
                                        </div>
                                    </div>
                                </form>
                            </div>
                            <div class="modal-footer">
                                <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

<?php

// Get footer
include('admin_footer.inc.php');
