<?php
/*
 * This file is part of LinkMan - PHP Links Manager.
 *
 * (c) Copyright 2016 by Klemen Stirn. All rights reserved.
 * http://www.phpjunkyard.com
 * http://www.phpjunkyard.com/php-link-manager.php
 *
 * For the full copyright and license agreement information, please view
 * the docs/index.html file that was distributed with this source code.
 */

define('IN_SCRIPT', 1);
define('THIS_PAGE', 'EDITLINK');

// Require the settings file
require '../config/settings.php';

// Load functions
require '../inc/common.inc.php';

// Start session
pj_session_start();

// Are we logged in?
pj_isLoggedIn(true);

// The settings file is in parent folder
$settings['db_file'] = '../config/' . $settings['db_file'];

// Pre-set values
$error_buffer = array();
$warn_new_link = false;

// Get links database
$data = explode('//', file_get_contents($settings['db_file']), 2);

// Convert contents into an array
$database = isset($data[1]) ? unserialize($data[1]) : array();
unset($data);

// Link ID
$id = preg_replace('/[^0-9a-zA-Z_\-\.]/', '', pj_REQUEST('id'));

// Link ID exists?
if (strlen($id) < 1 || !isset($database[$id])) {
    $_SESSION['PJ_MESSAGES']['ERROR'] = 'Invalid link ID';
    header('Location: admin.php');
    exit();
}

// Add a new link?
if (pj_POST('action') == 'save' && pj_token_check()) {
    // Check demo mode
    pj_demo('edit_link.php?id=' . $id);

    // Owner name
    $database[$id]['N'] = stripslashes(pj_input(pj_POST('name'))) or $error_buffer['name'] = 'Enter website owner name.';

    // Owner email
    $database[$id]['E'] = pj_validateEmail(pj_POST('email')) or $error_buffer['email'] = 'Enter a valid website owner email address.';

    // Website title
    $database[$id]['T'] = stripslashes(pj_input(pj_POST('title'))) or $error_buffer['title'] = 'Enter website title.';

    // Website description
    $database[$id]['S'] = stripslashes(pj_input(pj_POST('description'))) or $error_buffer['description'] = 'Enter website description.';

    // Link URL
    $database[$id]['L'] = pj_validateURL(pj_POST('url')) or $error_buffer['url'] = 'Enter a valid website URL address.';

    // Reciprocal URL
    $database[$id]['R'] = pj_POST('recurl', '');
    if (strlen($database[$id]['R']) && !pj_validateURL($database[$id]['R'])) {
        $error_buffer['recurl'] = 'This is not a valid URL address. Leave empty if you do not require a reciprocal link.';
    }

    // Featured?
    $database[$id]['F'] = pj_POST('featured') == 1 ? 1 : 0;

    // If no errors, save changes
    if (count($error_buffer) == 0) {
        // Update database file
        if (@file_put_contents($settings['db_file'], "<?php die();//" . serialize($database), LOCK_EX) === false) {
            $_SESSION['PJ_MESSAGES']['ERROR'] = 'Error writing to database file, please try again later.';
        } else {
            $_SESSION['PJ_MESSAGES']['SUCCESS'] = 'Link changes saved.';
            $_SESSION['LAST_MODIFIED'] = $id;
            header('Location: admin.php');
            exit();
        }
    }
}

if (count($error_buffer)) {
    $_SESSION['PJ_MESSAGES']['ERROR'] = 'Missing or invalid data, see below for details.';
}

// Require admin header
require 'admin_header.inc.php';

?>

<?php pj_processMessages(); ?>

    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title">Editing link</h3>
                </div>
                <div class="panel-body">
                    <form action="edit_link.php" method="post"
                          name="addlinkform" class="form-horizontal">
                        <div
                            class="form-group<?php echo isset($error_buffer['name']) ? ' has-error' : ''; ?>">
                            <label for="name"
                                   class="col-lg-3 control-label bold">Owner
                                name:</label>
                            <div class="col-lg-9">
                                <input type="text" id="name" name="name"
                                       value="<?php echo $database[$id]['N']; ?>"
                                       size="50" maxlength="255"
                                       class="form-control"
                                       placeholder="John Doe">
                                <p class="help-block"><?php echo isset($error_buffer['name']) ? $error_buffer['name'] : 'Name of the website owner.'; ?></p>
                            </div>
                        </div>
                        <div
                            class="form-group<?php echo isset($error_buffer['email']) ? ' has-error' : ''; ?>">
                            <label for="email"
                                   class="col-lg-3 control-label bold">Owner
                                email:</label>
                            <div class="col-lg-9">
                                <input type="text" id="email" name="email"
                                       value="<?php echo defined('PJ_DEMO') ? 'some@example.com' : $database[$id]['E']; ?>"
                                       size="50" maxlength="255"
                                       class="form-control"
                                       placeholder="some@example.com">
                                <p class="help-block"><?php echo isset($error_buffer['email']) ? $error_buffer['email'] : 'Email address of the website owner.'; ?></p>
                            </div>
                        </div>
                        <div
                            class="form-group<?php echo isset($error_buffer['title']) ? ' has-error' : ''; ?>">
                            <label for="title"
                                   class="col-lg-3 control-label bold">Website
                                title:</label>
                            <div class="col-lg-9">
                                <input type="text" id="title" name="title"
                                       value="<?php echo $database[$id]['T']; ?>"
                                       maxlength="255" size="50"
                                       class="form-control"
                                       placeholder="My website">
                                <p class="help-block"><?php echo isset($error_buffer['title']) ? $error_buffer['title'] : 'Title of the website for links list.'; ?></p>
                            </div>
                        </div>
                        <div
                            class="form-group<?php echo isset($error_buffer['description']) ? ' has-error' : ''; ?>">
                            <label for="description"
                                   class="col-lg-3 control-label bold">Website
                                description:</label>
                            <div class="col-lg-9">
                                <input type="text" id="description"
                                       name="description"
                                       value="<?php echo $database[$id]['S']; ?>"
                                       maxlength="255" size="50"
                                       class="form-control"
                                       placeholder="Visit this website to learn more about...">
                                <p class="help-block"><?php echo isset($error_buffer['description']) ? $error_buffer['description'] : 'A short website description.'; ?></p>
                            </div>
                        </div>
                        <div
                            class="form-group<?php echo isset($error_buffer['url']) ? ' has-error' : ''; ?>">
                            <label for="url"
                                   class="col-lg-3 control-label bold">Website
                                URL:</label>
                            <div class="col-lg-9">
                                <input type="url" id="url" name="url"
                                       value="<?php echo $database[$id]['L']; ?>"
                                       size="50" class="form-control"
                                       placeholder="http://www.example.com">
                                <p class="help-block"><?php echo isset($error_buffer['url']) ? $error_buffer['url'] : 'Website URL to be shown on links list.'; ?></p>
                            </div>
                        </div>
                        <div
                            class="form-group<?php echo isset($error_buffer['recurl']) ? ' has-error' : ''; ?>">
                            <label for="recurl" class="col-lg-3 control-label">Reciprocal
                                link URL:</label>
                            <div class="col-lg-9">
                                <input type="url" id="recurl" name="recurl"
                                       value="<?php echo $database[$id]['R']; ?>"
                                       size="50" class="form-control"
                                       placeholder="(optional) http://www.example.com/links.html">
                                <p class="help-block"><?php echo isset($error_buffer['recurl']) ? $error_buffer['recurl'] : 'URL where a reciprocal link to your website is located. Leave empty if reciprocal link is not required.'; ?></p>
                            </div>
                        </div>
                        <div
                            class="form-group<?php echo isset($error_buffer['featured']) ? ' has-error' : ''; ?>">
                            <label for="featured"
                                   class="col-lg-3 control-label">Featured
                                link:</label>
                            <div class="col-lg-9">
                                <label class="radio-inline">
                                    <input type="radio" name="featured"
                                           id="featured1"
                                           value="1" <?php echo $database[$id]['F'] ? 'checked' : ''; ?> >
                                    YES
                                </label>
                                <label class="radio-inline">
                                    <input type="radio" name="featured"
                                           id="featured0"
                                           value="0" <?php echo $database[$id]['F'] ? '' : 'checked'; ?> >
                                    NO
                                </label>
                                <p class="help-block"><?php echo isset($error_buffer['featured']) ? $error_buffer['featured'] : 'Featured links appear at the top of all link pages.'; ?></p>
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-lg-offset-3 col-lg-9">
                                <input type="hidden" name="action" value="save">
                                <input type="hidden" name="token"
                                       value="<?php echo pj_token_get(); ?>">
                                <input type="hidden" name="id"
                                       value="<?php echo $id; ?>">
                                <button type="submit" class="btn btn-primary"><i
                                        class="glyphicon glyphicon-floppy-disk"></i>&nbsp;Save
                                    changes
                                </button>
                                <a href="admin.php" class="btn btn-default"
                                   role="button"><i
                                        class="glyphicon glyphicon-remove"></i>&nbsp;Cancel
                                    changes</a>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>

<?php

// Get footer
include('admin_footer.inc.php');

////////////////////////////////////////////////////////////////////////////////
// FUNCTIONS
////////////////////////////////////////////////////////////////////////////////

function pj_array_key_replace($array, $key1, $key2)
{
    $keys = array_keys($array);
    $index = array_search($key1, $keys);

    if ($index !== false) {
        $keys[$index] = $key2;
        $array = array_combine($keys, $array);
    }

    return $array;
} // END pj_array_key_replace()
