<?php
/*
 * This file is part of LinkMan - PHP Links Manager.
 *
 * (c) Copyright 2016 by Klemen Stirn. All rights reserved.
 * http://www.phpjunkyard.com
 * http://www.phpjunkyard.com/php-link-manager.php
 *
 * For the full copyright and license agreement information, please view
 * the docs/index.html file that was distributed with this source code.
 */

define('IN_SCRIPT', 1);
define('THIS_PAGE', 'NEWLINK');

// Require the settings file
require '../config/settings.php';

// Load functions
require '../inc/common.inc.php';

// Start session
pj_session_start();

// Are we logged in?
pj_isLoggedIn(true);

// The settings file is in parent folder
$settings['db_file'] = '../config/' . $settings['db_file'];

// Pre-set values
$name = '';
$email = '';
$url = '';
$title = '';
$description = '';
$recurl = '';
$featured = 0;
$error_buffer = array();

// Add a new link?
if (pj_POST('action') == 'add' && pj_token_check()) {
    // Check demo mode
    pj_demo('new_link.php');

    // Owner name
    $name = stripslashes(pj_input(pj_POST('name'))) or $error_buffer['name'] = 'Enter website owner name.';

    // Owner email
    $email = pj_validateEmail(pj_POST('email')) or $error_buffer['email'] = 'Enter a valid website owner email address.';

    // Website title
    $title = stripslashes(pj_input(pj_POST('title'))) or $error_buffer['title'] = 'Enter website title.';

    // Website description
    $description = stripslashes(pj_input(pj_POST('description'))) or $error_buffer['description'] = 'Enter website description.';

    // Link URL
    $url = pj_validateURL(pj_POST('url')) or $error_buffer['url'] = 'Enter a valid website URL address.';

    // Reciprocal URL
    $recurl = pj_POST('recurl', '');
    if (strlen($recurl) && !pj_validateURL($recurl)) {
        $error_buffer['recurl'] = 'This is not a valid URL address. Leave empty if you do not require a reciprocal link.';
    }

    // Featured?
    $featured = pj_POST('featured') == 1 ? 1 : 0;

    // If no errors, check for duplicates/generate a new ID
    if (count($error_buffer) == 0) {
        // Get links database
        $data = explode('//', file_get_contents($settings['db_file']), 2);

        // Convert contents into an array
        $database = isset($data[1]) ? unserialize($data[1]) : array();
        unset($data);

        // Generate next ID
        $id = count($database) ? max(array_keys($database)) : 0;
        $id++;

        // Generate link array
        reset($database);
        $database[$id] = array('D' => date('Y-m-d'), 'L' => $url, 'R' => $recurl, 'T' => $title, 'S' => $description, 'N' => $name, 'E' => $email, 'F' => $featured, 'O' => $settings['add_to']);
        uasort($database, 'sort_order');
        reset_sort_order($database);

        // Update database file
        if (@file_put_contents($settings['db_file'], "<?php die();//" . serialize($database), LOCK_EX) === false) {
            $_SESSION['PJ_MESSAGES']['ERROR'] = 'Error writing to database file, please try again later.';
        } else {
            $_SESSION['PJ_MESSAGES']['SUCCESS'] = 'New link added to the link exchange!';

            $name = '';
            $email = '';
            $url = '';
            $title = '';
            $description = '';
            $recurl = '';
            $featured = 0;
        }
    }
}

if (count($error_buffer)) {
    $_SESSION['PJ_MESSAGES']['ERROR'] = 'Missing or invalid data, see below for details.';
}

// Require admin header
require 'admin_header.inc.php';

?>

<?php pj_processMessages(); ?>

    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title">Add a new link to the exchange</h3>
                </div>
                <div class="panel-body">
                    <form action="new_link.php" method="post" name="addlinkform"
                          class="form-horizontal">
                        <div
                            class="form-group<?php echo isset($error_buffer['name']) ? ' has-error' : ''; ?>">
                            <label for="name"
                                   class="col-lg-3 control-label bold">Owner
                                name:</label>
                            <div class="col-lg-9">
                                <input type="text" id="name" name="name"
                                       value="<?php echo $name; ?>" size="50"
                                       maxlength="255" class="form-control"
                                       placeholder="John Doe">
                                <p class="help-block"><?php echo isset($error_buffer['name']) ? $error_buffer['name'] : 'Name of the website owner.'; ?></p>
                            </div>
                        </div>
                        <div
                            class="form-group<?php echo isset($error_buffer['email']) ? ' has-error' : ''; ?>">
                            <label for="email"
                                   class="col-lg-3 control-label bold">Owner
                                email:</label>
                            <div class="col-lg-9">
                                <input type="text" id="email" name="email"
                                       value="<?php echo $email; ?>" size="50"
                                       maxlength="255" class="form-control"
                                       placeholder="some@example.com">
                                <p class="help-block"><?php echo isset($error_buffer['email']) ? $error_buffer['email'] : 'Email address of the website owner.'; ?></p>
                            </div>
                        </div>
                        <div
                            class="form-group<?php echo isset($error_buffer['title']) ? ' has-error' : ''; ?>">
                            <label for="title"
                                   class="col-lg-3 control-label bold">Website
                                title:</label>
                            <div class="col-lg-9">
                                <input type="text" id="title" name="title"
                                       value="<?php echo $title; ?>"
                                       maxlength="255" size="50"
                                       class="form-control"
                                       placeholder="My website">
                                <p class="help-block"><?php echo isset($error_buffer['title']) ? $error_buffer['title'] : 'Title of the website for links list.'; ?></p>
                            </div>
                        </div>
                        <div
                            class="form-group<?php echo isset($error_buffer['description']) ? ' has-error' : ''; ?>">
                            <label for="description"
                                   class="col-lg-3 control-label bold">Website
                                description:</label>
                            <div class="col-lg-9">
                                <input type="text" id="description"
                                       name="description"
                                       value="<?php echo $description; ?>"
                                       maxlength="255" size="50"
                                       class="form-control"
                                       placeholder="Visit this website to learn more about...">
                                <p class="help-block"><?php echo isset($error_buffer['description']) ? $error_buffer['description'] : 'A short website description.'; ?></p>
                            </div>
                        </div>
                        <div
                            class="form-group<?php echo isset($error_buffer['url']) ? ' has-error' : ''; ?>">
                            <label for="url"
                                   class="col-lg-3 control-label bold">Website
                                URL:</label>
                            <div class="col-lg-9">
                                <input type="url" id="url" name="url"
                                       value="<?php echo $url; ?>" size="50"
                                       class="form-control"
                                       placeholder="http://www.example.com">
                                <p class="help-block"><?php echo isset($error_buffer['url']) ? $error_buffer['url'] : 'Website URL to be shown on links list.'; ?></p>
                            </div>
                        </div>
                        <div
                            class="form-group<?php echo isset($error_buffer['recurl']) ? ' has-error' : ''; ?>">
                            <label for="recurl" class="col-lg-3 control-label">Reciprocal
                                link URL:</label>
                            <div class="col-lg-9">
                                <input type="url" id="recurl" name="recurl"
                                       value="<?php echo $recurl; ?>" size="50"
                                       class="form-control"
                                       placeholder="(optional) http://www.example.com/links.html">
                                <p class="help-block"><?php echo isset($error_buffer['recurl']) ? $error_buffer['recurl'] : 'URL where a reciprocal link to your website is located. Leave empty if reciprocal link is not required.'; ?></p>
                            </div>
                        </div>
                        <div
                            class="form-group<?php echo isset($error_buffer['featured']) ? ' has-error' : ''; ?>">
                            <label for="featured"
                                   class="col-lg-3 control-label">Featured
                                link:</label>
                            <div class="col-lg-9">
                                <label class="radio-inline">
                                    <input type="radio" name="featured"
                                           id="featured1"
                                           value="1" <?php echo $featured ? 'checked' : ''; ?> >
                                    YES
                                </label>
                                <label class="radio-inline">
                                    <input type="radio" name="featured"
                                           id="featured0"
                                           value="0" <?php echo $featured ? '' : 'checked'; ?> >
                                    NO
                                </label>
                                <p class="help-block"><?php echo isset($error_buffer['featured']) ? $error_buffer['featured'] : 'Featured links appear at the top of all link pages.'; ?></p>
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-lg-offset-3 col-lg-9">
                                <input type="hidden" name="action" value="add">
                                <input type="hidden" name="token"
                                       value="<?php echo pj_token_get(); ?>">
                                <button type="submit" class="btn btn-primary"><i
                                        class="glyphicon glyphicon-plus"></i>&nbsp;Add
                                    this link
                                </button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>

<?php

// Get footer
include('admin_footer.inc.php');
