<?php
/*
 * This file is part of LinkMan - PHP Links Manager.
 *
 * (c) Copyright 2016 by Klemen Stirn. All rights reserved.
 * http://www.phpjunkyard.com
 * http://www.phpjunkyard.com/php-link-manager.php
 *
 * For the full copyright and license agreement information, please view
 * the docs/index.html file that was distributed with this source code.
 */

define('IN_SCRIPT', 1);
define('THIS_PAGE', 'PENDING');

// Require the settings file
require '../config/settings.php';

// If this function is disabled redirect to main admin page
if (!$settings['man_approval']) {
    header('Location: admin.php');
    exit();
}

// Load functions
require '../inc/common.inc.php';

// Load verification functions
require '../inc/verify.inc.php';

// Start session
pj_session_start();

// Are we logged in?
pj_isLoggedIn(true);

// The database file is in parent folder
$settings['db_file'] = '../config/' . $settings['db_file'];

// Require admin header
require 'admin_header.inc.php';

?>

<?php pj_processMessages(); ?>

    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default" style="min-height: 300px">

                <div class="panel-body">

                    <p>This is a list of websites that require manual review and approval to be accepted to the exchange.<br/>&nbsp;</p>

                    <?php
                    // Use demo or actual data?
                    if (defined('PJ_DEMO')) {
                        $links = array('demo');
                    } else {
                        // Read app_tmp folder for pending links
                        $files = scandir('../tmp');
                        $links = array();

                        // Process each file
                        foreach ($files as $file) {
                            if (preg_match('/^([a-f0-9]{40}\.php)$/', $file)) {
                                $links[] = $file;
                            }
                        }
                    }

                    // Do we have any pending links?
                    if (count($links) == 0) {
                        pj_showInfo('No links are currently pending approval.');
                    } // We have some pending links to show...
                    else {
                        $i = 0;

                        // Loop through all links
                        foreach ($links as $link) {
                            // Get special tags from the file
                            $special_tags = pj_get_tmp_array($link, '');

                            // An invalid link?
                            if ($special_tags === false) {
                                continue;
                            }

                            $i++;

                            // Print the link
                            ?>

                            <script type="text/javascript">
                                $(document).ready(function () {

                                    $(".approve<?php echo $i; ?>").on("click", function () {

                                        $.get("approve.php", {
                                                jquery: "1",
                                                approve: "1",
                                                key: "<?php echo substr($link, 0, -4); ?>"
                                            })
                                            .done(function (data) {

                                                if (data == 'APPROVED') {
                                                    $("#msg<?php echo $i; ?>").text('Link approved!')
                                                    $("#panel<?php echo $i; ?>").hide();
                                                    $("#alert<?php echo $i; ?>").addClass('alert-success').removeClass('hide');
                                                }
                                                else {
                                                    alert("Error: " + data);
                                                }

                                            });

                                    });

                                    $(".reject<?php echo $i; ?>").on("click", function () {

                                        $.get("approve.php", {
                                                jquery: "1",
                                                approve: "0",
                                                key: "<?php echo substr($link, 0, -4); ?>"
                                            })
                                            .done(function (data) {

                                                if (data == 'REJECTED') {
                                                    $("#msg<?php echo $i; ?>").text('Link rejected!')
                                                    $("#panel<?php echo $i; ?>").hide();
                                                    $("#alert<?php echo $i; ?>").addClass('alert-danger').removeClass('hide');
                                                }
                                                else {
                                                    alert("Error: " + data);
                                                }

                                            });

                                    });

                                });
                            </script>

                            <div class="panel panel-default" id="panel<?php echo $i; ?>">
                                <div class="panel-body">
                                    <dl class="dl-horizontal dl-approve">
                                        <dt>Owner:</dt>
                                        <dd><?php echo $special_tags['{NAME}']; ?> &lt;<a href="<?php echo $special_tags['{EMAIL}']; ?>"><?php echo $special_tags['{EMAIL}']; ?></a>&gt;</dd>
                                        <dt>Website:</dt>
                                        <dd><a href="<?php echo $special_tags['{URL}']; ?>"><?php echo $special_tags['{TITLE}']; ?></a></dd>
                                        <dt>Description:</dt>
                                        <dd><?php echo $special_tags['{DESCRIPTION}']; ?></dd>
                                        <dt>Reciprocal link:</dt>
                                        <dd><a href="<?php echo $special_tags['{RECURL}']; ?>"><?php echo $special_tags['{RECURL}']; ?></a></dd>
                                    </dl>
                                </div>
                                <div class="panel-footer">
                                    <dl class="dl-horizontal dl-approve">
                                        <dt>&nbsp;</dt>
                                        <dd>
                                            <button type="button" class="btn btn-success approve<?php echo $i; ?>"><i class="glyphicon glyphicon-ok"></i>&nbsp;Approve</button>
                                            <button type="button" class="btn btn-danger reject<?php echo $i; ?>"><i class="glyphicon glyphicon-remove"></i>&nbsp;Reject</button>
                                        </dd>
                                    </dl>
                                </div>
                            </div>

                            <div class="alert hide alert-dismissable" role="alert" id="alert<?php echo $i; ?>">
                                <button type="button" class="close" data-dismiss="alert"><span aria-hidden="true">&times;</span><span class="sr-only">Close</span></button>
                                <div id="msg<?php echo $i; ?>"></div>
                            </div>

                            <?php
                        }

                    } // END showing pending links
                    ?>

                </div>

            </div>
        </div>
    </div>

<?php

// Get footer
include('admin_footer.inc.php');
