<?php
/*
 * This file is part of LinkMan - PHP Links Manager.
 *
 * (c) Copyright 2016 by Klemen Stirn. All rights reserved.
 * http://www.phpjunkyard.com
 * http://www.phpjunkyard.com/php-link-manager.php
 *
 * For the full copyright and license agreement information, please view
 * the docs/index.html file that was distributed with this source code.
 */

define('IN_SCRIPT', 1);
define('THIS_PAGE', 'VERIFY');

// Require the settings file
require '../config/settings.php';

// Load functions
require '../inc/common.inc.php';

// Start session
pj_session_start();

// Are we logged in?
pj_isLoggedIn(true);

// Get url of verify_links.php
if (isset($_SERVER['HTTP_HOST']) && isset($_SERVER['REQUEST_URI']) && strpos($_SERVER['REQUEST_URI'], '/verify.php') !== false) {
    $settings['url_verify'] = 'http://' . $_SERVER['HTTP_HOST'] . str_replace('/verify.php', '/verify_links.php', $_SERVER['REQUEST_URI']);
} else {
    $settings['url_verify'] = 'http://example.com/links/admin/verify_links.php';
}

// Hide sensitive settings in demo mode
if (defined('PJ_DEMO')) {
    $settings['access_key'] = 'abcde';
}

// Require admin header
require 'admin_header.inc.php';

?>

<?php pj_processMessages(); ?>

    <script type="text/javascript">
        $(document).ready(function () {
            // load the frame on button click
            $('#verify').click(function () {
                $("#verify-results").attr("src", "verify_links.php?token=<?php echo pj_token_get(); ?>&" + $("input").serialize());
            });

            // save checkbox state: read the current/previous setting
            $("input.box").each(function() {
                var mycookie = $.cookie($(this).attr('name'));
                if (mycookie && mycookie == "true") {
                    $(this).prop('checked', mycookie);
                }
            });

            // save checkbox state: event management
            $("input.box").change(function() {
                $.cookie($(this).attr("name"), $(this).prop('checked'), {
                    path: '/',
                    expires: 365
                });
            });

            // generate verify link code on button click
            $('#verifyLink').click(function () {
                $( "#verifyCode" ).val("<?php echo $settings['url_verify']; ?>?key=<?php echo urlencode($settings['access_key']); ?>&" + $("input").serialize());
                $( "#verifyCron" ).val("wget --header=\"Accept: text/html\" --user-agent=\"<?php echo $settings['user_agent']; ?>\" -O - \"<?php echo $settings['url_verify']; ?>?key=<?php echo urlencode($settings['access_key']); ?>&" + $("input").serialize() + "\"");
            });

            // Select all in textarea
            $("input.autoselect").focus(function() {
                var $this = $(this);
                $this.select();

                // Work around Chrome's little problem
                $this.mouseup(function() {
                    // Prevent further mouseup intervention
                    $this.unbind("mouseup");
                    return false;
                });
            });
        });
    </script>

    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title">Verify links</h3>
                </div>
                <div class="panel-body">

                    <p>This tool will check all links in the link exchange to make sure they are still valid and that reciprocal link is present.</p>

                    <form name="verify_options" id="verify_options">
                        <div class="form-group">
                            <strong>Remove websites from the exchange if:</strong>
                            <div class="checkbox">
                                <label>
                                    <input type="checkbox" class="box" name="remove_site_down" id="remove_site_down" value="1"> website cannot be opened
                                </label>
                            </div>
                            <div class="checkbox">
                                <label>
                                    <input type="checkbox" class="box" name="remove_page_down" id="remove_page_down" value="1"> reciprocal links page cannot be opened
                                </label>
                            </div>
                            <div class="checkbox">
                                <label>
                                    <input type="checkbox" class="box" name="remove_not_found" id="remove_not_found" value="1"> reciprocal link is missing
                                </label>
                            </div>
                            <div class="checkbox">
                                <label>
                                    <input type="checkbox" class="box" name="remove_nofollow" id="remove_nofollow" value="1"> reciprocal link contains <i>nofollow</i> tag
                                </label>
                            </div>
                            <div class="checkbox">
                                <label>
                                    <input type="checkbox" class="box" name="remove_cheaters" id="remove_cheaters" value="1"> a cheating reciprocal link is detected
                                </label>
                            </div>
                        </div>

                        <p>
                            <button type="button" class="btn btn-primary" id="verify"><i class="glyphicon glyphicon-check"></i>&nbsp;Start link verification</button>
                            <button type="button" class="btn btn-default" id="verifyLink" data-toggle="modal" data-target="#verifyModal">Generate verification URL</button>
                        </p>

                    </form>

                    <iframe src="" id="verify-results" frameborder="1" height="400" width="100%"></iframe>

                </div>
            </div>
        </div>
    </div>


    <!-- Modal -->
    <div class="modal fade" id="verifyModal" tabindex="-1" role="dialog" aria-labelledby="verifyModal">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-body">
                    <p><strong>Auto-verify links URL:</strong></p>
                    <p>Open this URL (in a browser, using wget in a Cron job, ...) to run link verification without having to login into the admin panel:</p>
                    &nbsp;
                    <input type="text" class="form-control autoselect" id="verifyCode">
                    &nbsp;
                    <p><strong>Sample Cron job command using wget:</strong></p>
                    <input type="text" class="form-control autoselect" id="verifyCron">
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>

<?php

// Get footer
include('admin_footer.inc.php');
