<?php
/*
 * This file is part of LinkMan - PHP Links Manager.
 *
 * (c) Copyright 2016 by Klemen Stirn. All rights reserved.
 * http://www.phpjunkyard.com
 * http://www.phpjunkyard.com/php-link-manager.php
 *
 * For the full copyright and license agreement information, please view
 * the docs/index.html file that was distributed with this source code.
 */

// Check if this is a valid include
if (!defined('IN_SCRIPT')) {
    die('Invalid attempt');
}

// Load PHPMailer
require 'inc/PHPMailer/PHPMailerAutoload.php';


////////////////////////////////////////////////////////////////////////////////
// FUNCTIONS
////////////////////////////////////////////////////////////////////////////////


function pj_mail($to, $name, $subject, $message, $message_alt = '')
{
    global $settings;

    // Demo mode
    if ( defined('PJ_DEMO') )
    {
        return true;
    }

    // Create a new PHPMailer instance
    $mail = new PHPMailer();

    // We are using UTF-8 charset
    $mail->CharSet = 'utf-8';

    // Use SMTP?
    if ($settings['smtp'])
    {
        // Tell PHPMailer to use SMTP
        $mail->isSMTP();

        // Enable SMTP debugging?
        $mail->SMTPDebug = 0;

        // Ask for HTML-friendly debug output
        $mail->Debugoutput = 'html';

        // Set the hostname of the mail server
        $mail->Host = $settings['smtp_host_name'];

        // Set the SMTP port number
        $mail->Port = $settings['smtp_host_port'];

        // Use encryption system?
        if ($settings['smtp_secure'])
        {
            $mail->SMTPSecure = $settings['smtp_secure'];
        }

        // Use SMTP authentication?
        if ($settings['smtp_user'])
        {
            $mail->SMTPAuth = true;

            // Username to use for SMTP authentication - use full email address for gmail
            $mail->Username = $settings['smtp_user'];

            // Password to use for SMTP authentication
            $mail->Password = $settings['smtp_password'];
        }
    }

    // Set who the message is to be sent from
    $mail->setFrom($settings['webmaster_email'], $settings['webmaster_name']);

    // Set an alternative reply-to address
    $mail->addReplyTo($settings['webmaster_email'], $settings['webmaster_name']);

    // Set who the message is to be sent to
    $mail->addAddress($to, $name);

    // Set email format to HTML
    $mail->isHTML(true);

    // Set the subject line
    $mail->Subject = $subject;

    // Set the email body (message)
    $mail->msgHTML($message);

    // Overwrite alternative (plain text) email body?
    if ( ! $message_alt)
    {
        require 'inc/html2text/html2text.php';
        $message_alt = convert_html_to_text($message);
    }
    $mail->AltBody = $message_alt;

    //send the message, check for errors
    if (!$mail->send())
    {
        $_SESSION['PJ_MESSAGES']['WARNING'] = "Could not send email notifications";

        if ($settings['debug']) {
            $_SESSION['PJ_MESSAGES']['WARNING'] .= "<br><br>Debug: " . $mail->ErrorInfo;
        }
    }

    return true;
} // END pj_mail()


function pj_get_mail_body($template, $special_tags)
{
    global $settings;

    // Allowed templates
    $ok_templates = array(
        'admin_approve_link',
        'admin_new_link',
    );

    // Is the template valid?
    if ( ! in_array($template, $ok_templates) )
    {
        die('Invalid email template');
    }

    $template_file = 'admin/emails/'.$template.'.html';

    // Does the template exist?
    if ( ! file_exists($template_file) )
    {
        die('Email template missing');
    }

    // Read the template
    $message = file_get_contents($template_file);

    // Global special tags
    $special_tags['{SITE_URL}'] = $settings['site_url'];
    $special_tags['{SITE_TITLE}'] = $settings['site_title'];
    $special_tags['{WEBMASTER_NAME}'] = $settings['webmaster_name'];
    $special_tags['{WEBMASTER_EMAIL}'] = $settings['webmaster_email'];

    // Replace special tags
    $message = str_replace( array_keys($special_tags), array_values($special_tags), $message );

    return $message;

} // END pj_get_mail_body()
