<?php
/*
 * This file is part of LinkMan - PHP Links Manager.
 *
 * (c) Copyright 2016 by Klemen Stirn. All rights reserved.
 * http://www.phpjunkyard.com
 * http://www.phpjunkyard.com/php-link-manager.php
 *
 * For the full copyright and license agreement information, please view
 * the docs/index.html file that was distributed with this source code.
 */

define('IN_SCRIPT', 1);
define('THIS_PAGE', 'SETTINGS');

// Require the settings file
require '../config/settings.php';

// Load functions
require '../inc/common.inc.php';

// Start session
pj_session_start();

// Are we logged in?
pj_isLoggedIn(true);

// Used if we need to load a different tab
$load_tab = '';

// Used to track which tabs we need to color in case of errors
$error_tabs = array();

// Buffer for containing error messages
$error_buffer = array();

// Add a new link?
if (pj_POST('action') == 'save' && pj_token_check()) {
    // Check demo mode
    pj_demo('edit_settings.php');

    // No errors yet...
    $num_errors = 0;

    // ==> GENERAL

    // Admin password
    $settings['admin_pass'] = pj_input(pj_POST('admin_pass')) or $error_buffer['admin_pass'] = 'Choose a password you will use to access admin pages.';

    // Webmaster name
    $settings['webmaster_name'] = pj_input(pj_POST('webmaster_name')) or $error_buffer['webmaster_name'] = 'Enter your name or the name of your business.';

    // Webmaster email
    $settings['webmaster_email'] = pj_validateEmail(pj_POST('webmaster_email')) or $error_buffer['webmaster_email'] = 'Enter a valid email address.';

    // Website URL
    $settings['site_url'] = pj_validateURL(pj_POST('site_url')) or $error_buffer['site_url'] = 'Enter a valid website URL. This is the website users will link to.';

    // Website title
    $settings['site_title'] = pj_input(pj_POST('site_title')) or $error_buffer['site_title'] = 'Enter your website title (for link anchor text).';

    // Website description
    $settings['site_desc'] = pj_input(pj_POST('site_desc')) or $error_buffer['site_desc'] = 'Enter a short website description.';

    // Do we need to activate this tab?
    if (($tmp = count($error_buffer)) > $num_errors) {
        $num_errors = $tmp;
        $error_tabs[] = 'general';
        $load_tab = ($load_tab == '') ? 'general' : $load_tab;
    }


    // ==> EXCHANGE OPTIONS

    // Block links with "nofollow" attribute
    $settings['block_nofollow'] = pj_POST('block_nofollow', 1) ? 1 : 0;

    // Block words like best, biggest, largest
    $settings['superlatives'] = pj_POST('superlatives', 1) ? 1 : 0;

    // Block duplicate links
    $settings['block_duplicates'] = pj_POST('block_duplicates', 1) ? 1 : 0;

    // Where to add new links? 0 = top of list, 1000000 = end of list
    $settings['add_to'] = pj_POST('add_to', 0) ? 1000000 : 0;

    // Do we need to activate this tab?
    if (($tmp = count($error_buffer)) > $num_errors) {
        $num_errors = $tmp;
        $error_tabs[] = 'exchange';
        $load_tab = ($load_tab == '') ? 'exchange' : $load_tab;
    }

    // ==> DISPLAY OPTIONS

    // Public language
    $settings['language'] = pj_input(pj_POST('language', 'en-US')) or $error_buffer['language'] = 'Select a language that will be used for public pages.';

    // Check language folder name
    if (!isset($error_buffer['language']) && preg_match('/[^0-9a-zA-Z_\-]/', $settings['language'])) {
        $error_buffer['language'] = 'Invalid language folder name. Use only these chars: a-z A-Z 0-9 _ -';
    }

    // Does the language folder exist?
    if (!isset($error_buffer['language']) && !is_dir('../language/' . $settings['language'])) {
        $error_buffer['language'] = "This language folder does not exist.";
    }

    // Check the public.php language file
    if (!isset($error_buffer['language'])) {
        if (file_exists('../language/' . $settings['language'] . '/public.php')) {
            if (pj_has_BOM(file_get_contents('../language/' . $settings['language'] . '/public.php', null, null, null, 3))) {
                $error_buffer['language'] = "UTF-8 BOM detected inside {$settings['language']}/public.php - <a href=\"http://www.phpjunkyard.com/support/kb/knowledgebase.php?article=40\">Remove BOM from the file</a>";
            }
        } else {
            $error_buffer['language'] = "File public.php is missing in the language folder.";
        }
    }

    // Public template
    $settings['template'] = pj_input(pj_POST('template', 'default')) or $error_buffer['template'] = 'Select a template that will be used for public pages.';

    // Check template name
    if (!isset($error_buffer['template']) && preg_match('/[^0-9a-zA-Z_\-]/', $settings['template'])) {
        $error_buffer['template'] = 'Invalid template name. Use only these chars: a-z A-Z 0-9 _ -';
    }

    // Does the template folder exist?
    if (!isset($error_buffer['template']) && !is_dir('../templates/' . $settings['template'])) {
        $error_buffer['template'] = "The {$settings['template']} template folder does not exist.";
    }

    // Number of links per page, default to 30
    $settings['max_per_page'] = intval(pj_POST('max_per_page', 30));
    if ($settings['max_per_page'] < 1 || $settings['max_per_page'] > 1000000) {
        $settings['max_per_page'] = 30;
    }

    // Use normal links? 0=NORMAL, 1=REDIRECT ALL, 2=REDIRECT RECIPROCAL ONLY
    $settings['redirect'] = intval(pj_POST('redirect', 0));
    if ($settings['redirect'] < 0 || $settings['redirect'] > 2) {
        $settings['redirect'] = 0;
    }

    // Add rel="nofollow" attribute to links? 0=NO, 1=YES, 2=FOR RECIPROCAL ONLY
    $settings['use_nofollow'] = intval(pj_POST('use_nofollow', 0));
    if ($settings['use_nofollow'] < 0 || $settings['use_nofollow'] > 2) {
        $settings['use_nofollow'] = 0;
    }

    // Display website thumbnails? 0=NO, 1=YES, 2=FEATURED LINKS ONLY
    $settings['show_thumbshots'] = intval(pj_POST('show_thumbshots', 0));
    if ($settings['show_thumbshots'] < 0 || $settings['show_thumbshots'] > 2) {
        $settings['show_thumbshots'] = 0;
    }

    // Thumbnails service URL
    $settings['thumb_url'] = pj_validateURL(pj_POST('thumb_url'));

    // Do we need a thumbnails URL?
    if ($settings['show_thumbshots'] && !strlen($settings['thumb_url'])) {
        $error_buffer['thumb_url'] = 'Enter a valid URL address of your <a href="http://www.phpjunkyard.com/support/kb/knowledgebase.php?article=43">thumbnail service</a>.';
    }

    // Do we need to activate this tab?
    if (($tmp = count($error_buffer)) > $num_errors) {
        $num_errors = $tmp;
        $error_tabs[] = 'display';
        $load_tab = ($load_tab == '') ? 'display' : $load_tab;
    }

    // ==> EMAIL OPTIONS

    // Send email notification of new links?
    $settings['notify'] = pj_POST('notify', 1) ? 1 : 0;

    // Use SMTP to send emails?
    $settings['smtp'] = pj_POST('smtp', 0) ? 1 : 0;

    // Do we need to collect other SMTP settings?
    if ($settings['smtp']) {
        // SMTP host
        $settings['smtp_host_name'] = pj_input(pj_POST('smtp_host_name')) or $error_buffer['smtp_host_name'] = 'Enter your SMTP host.';

        // SMTP port
        $settings['smtp_host_port'] = intval(pj_POST('smtp_host_port', 0));
        if ($settings['smtp_host_port'] < 0) {
            $settings['smtp_host_port'] = 25;
        }

        // SMTP connection type: 'tls' or 'ssl' or empty
        $settings['smtp_secure'] = pj_POST('smtp_secure', '');
        if ($settings['smtp_secure'] != 'tls' && $settings['smtp_secure'] != 'ssl') {
            $settings['smtp_secure'] = '';
        }

        // SMTP username
        $settings['smtp_user'] = pj_input(pj_POST('smtp_user'));

        // SMTP password
        $settings['smtp_password'] = pj_input(pj_POST('smtp_password'));
    }
    /*
    else
    {
        // Use default values
        $settings['smtp_host_name'] = 'mail.example.com';
        $settings['smtp_host_port'] = 25;
        $settings['smtp_secure'] = '';
        $settings['smtp_user'] = '';
        $settings['smtp_password'] = '';
    }
    */

    // Do we need to activate this tab?
    if (($tmp = count($error_buffer)) > $num_errors) {
        $num_errors = $tmp;
        $error_tabs[] = 'email';
        $load_tab = ($load_tab == '') ? 'email' : $load_tab;
    }


    // ==> SPAM PREVENTION

    // Enable SPAM filter?
    $settings['spam_filter'] = pj_POST('spam_filter', 1) ? 1 : 0;

    // Ban websites that fail the SPAM filter?
    $settings['ban_spam'] = pj_POST('ban_spam', 0) ? 1 : 0;

    // Ban websites with link passed in query string?
    $settings['ban_link_in_query'] = pj_POST('ban_link_in_query', 1) ? 1 : 0;

    // Approve links manually?
    $settings['man_approval'] = pj_POST('man_approval', 0) ? 1 : 0;

    // URL of the approve.php file on your server
    $settings['url_approval'] = pj_validateURL(pj_POST('url_approval')) or $error_buffer['url_approval'] = 'Enter valid URL of the admin/approve.php file on your server.';

    // Use security question?
    $settings['question_use'] = pj_POST('question_use', 0) ? 1 : 0;

    // Security question
    $settings['question_ask'] = pj_input(pj_POST('question_ask'));

    // Answer to security question
    $settings['question_ans'] = pj_input(pj_POST('question_ans'));

    // Use a simple security image?
    $settings['secimg_use'] = pj_POST('secimg_use', 1) ? 1 : 0;

    // Use reCaptcha?
    $settings['recaptcha_use'] = pj_POST('recaptcha_use', 0) ? 1 : 0;

    // Do we need extra reCaptcha settings?
    if ($settings['recaptcha_use']) {
        // reCaptcha site key
        $settings['recaptcha_site_key'] = pj_input(pj_POST('recaptcha_site_key')) or $error_buffer['recaptcha_site_key'] = 'Enter your reCaptcha site key.';

        // reCaptcha secret key
        $settings['recaptcha_secret_key'] = pj_input(pj_POST('recaptcha_secret_key')) or $error_buffer['smtp_host_name'] = 'Enter your reCaptcha private key.';
    }
    /*
    else
    {
        // Use default values
        $settings['recaptcha_site_key'] = '';
        $settings['recaptcha_secret_key'] = '';
    }
    */

    // Do we need to activate this tab?
    if (($tmp = count($error_buffer)) > $num_errors) {
        $num_errors = $tmp;
        $error_tabs[] = 'spam';
        $load_tab = ($load_tab == '') ? 'spam' : $load_tab;
    }


    // ==> MISC

    // LinkMan User Agent
    $settings['user_agent'] = pj_input(pj_POST('user_agent'));
    if (strlen($settings['user_agent']) == 0) {
        $settings['user_agent'] = isset($_SERVER['HTTP_USER_AGENT']) ? pj_input($_SERVER['HTTP_USER_AGENT']) : 'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:44.0) Gecko/20100101 Firefox/44.0';
    }

    // Key used for automated link verification
    $settings['access_key'] = pj_input(pj_POST('access_key')) or $error_buffer['access_key'] = 'Enter an access key (password) for automated link verifications.';

    // Name of the file where link URLs and other info is stored
    $settings['db_file'] = pj_input(pj_POST('db_file', 'database.php')) or $error_buffer['db_file'] = 'Enter the name of your Linkman database file (default: database.php).';

    // Check database file name
    if (!isset($error_buffer['db_file']) && preg_match('/[^0-9a-zA-Z_\-\.]/', $settings['db_file'])) {
        $error_buffer['db_file'] = 'Invalid file name. Use only these chars: a-z A-Z 0-9 _ - .';
    }

    // Does the file exist?
    if (!isset($error_buffer['db_file']) && !file_exists('../config/' . $settings['db_file'])) {
        $error_buffer['db_file'] = 'This file does not exist.';
    }

    // Name of the file where banned websites are stored
    $settings['ban_file'] = pj_input(pj_POST('ban_file', 'banned.php')) or $error_buffer['ban_file'] = 'Enter the name of your Linkman banned websites file (default: banned.php).';

    // Check banned file name
    if (!isset($error_buffer['ban_file']) && preg_match('/[^0-9a-zA-Z_\-\.]/', $settings['ban_file'])) {
        $error_buffer['ban_file'] = 'Invalid file name. Use only these chars: a-z A-Z 0-9 _ - .';
    }

    // Does the file exist?
    if (!isset($error_buffer['ban_file']) && !file_exists('../config/' . $settings['ban_file'])) {
        $error_buffer['ban_file'] = 'This file does not exist.';
    }

    // Turn debug mode on?
    $settings['debug'] = pj_POST('debug', 0) ? 1 : 0;

    // Do we need to activate this tab?
    if (($tmp = count($error_buffer)) > $num_errors) {
        $num_errors = $tmp;
        $error_tabs[] = 'misc';
        $load_tab = ($load_tab == '') ? 'misc' : $load_tab;
    }


    // ==> INTERNAL
    $settings['salt_pass'] = strlen($settings['salt_pass']) ? $settings['salt_pass'] : pj_random_salt();
    $settings['salt_spam'] = strlen($settings['salt_spam']) ? $settings['salt_spam'] : pj_random_salt();
    $settings['salt_temp'] = strlen($settings['salt_temp']) ? $settings['salt_temp'] : pj_random_salt();

    // Any errors?
    if (count($error_buffer) == 0) {
        // Update settings file
        if (@file_put_contents('../config/settings.php', "<?php
if (!defined('IN_SCRIPT')) {
    die('Invalid attempt!');
}

// ==> GENERAL

// Admin password
\$settings['admin_pass'] = '{$settings['admin_pass']}';

// Webmaster name
\$settings['webmaster_name'] = '{$settings['webmaster_name']}';

// Webmaster email
\$settings['webmaster_email'] = '{$settings['webmaster_email']}';

// Website URL
\$settings['site_url'] = '{$settings['site_url']}';

// Website title
\$settings['site_title'] = '{$settings['site_title']}';

// Website description
\$settings['site_desc'] = '{$settings['site_desc']}';

// ==> EXCHANGE OPTIONS

// Block links with \"nofollow\" attribute
\$settings['block_nofollow'] = {$settings['block_nofollow']};

// Block words like best, biggest, largest
\$settings['superlatives'] = {$settings['superlatives']};

// Block duplicate links
\$settings['block_duplicates'] = {$settings['block_duplicates']};

// Where to add new links? 0 = top of list, 1000000 = end of list
\$settings['add_to'] = {$settings['add_to']};

// ==> DISPLAY OPTIONS

// Public language
\$settings['language'] = '{$settings['language']}';

// Public template
\$settings['template'] = 'templates/{$settings['template']}';

// Number of links per page
\$settings['max_per_page'] = {$settings['max_per_page']};

// Use normal links? 0=NORMAL, 1=REDIRECT ALL, 2=REDIRECT RECIPROCAL ONLY
\$settings['redirect'] = {$settings['redirect']};

// Add rel=\"nofollow\" attribute to links? 0=NO, 1=YES, 2=FOR RECIPROCAL ONLY
\$settings['use_nofollow'] = {$settings['use_nofollow']};

// Display website thumbnails? 0=NO, 1=YES, 2=FEATURED LINKS ONLY
\$settings['show_thumbshots'] = {$settings['show_thumbshots']};

// Thumbnails service URL
\$settings['thumb_url'] = '{$settings['thumb_url']}';

// ==> EMAIL OPTIONS

// Send email notification of new links?
\$settings['notify'] = {$settings['notify']};

// Use SMTP to send emails?
\$settings['smtp'] = {$settings['smtp']};

// SMTP host
\$settings['smtp_host_name'] = '{$settings['smtp_host_name']}';

// SMTP port
\$settings['smtp_host_port'] = {$settings['smtp_host_port']};

// SMTP connection type: 'tls' or 'ssl' or empty
\$settings['smtp_secure'] = '{$settings['smtp_secure']}';

// SMTP username
\$settings['smtp_user'] = '{$settings['smtp_user']}';

// SMTP password
\$settings['smtp_password'] = '{$settings['smtp_password']}';

// ==> SPAM PREVENTION

// Enable SPAM filter?
\$settings['spam_filter'] = {$settings['spam_filter']};

// Ban websites that fail the SPAM filter?
\$settings['ban_spam'] = {$settings['ban_spam']};

// Ban websites with link passed in query string?
\$settings['ban_link_in_query'] = {$settings['ban_link_in_query']};

// Approve links manually?
\$settings['man_approval'] = {$settings['man_approval']};

// URL of the approve.php file on your server
\$settings['url_approval'] = '{$settings['url_approval']}';

// Use security question?
\$settings['question_use'] = {$settings['question_use']};

// Security question
\$settings['question_ask'] = '{$settings['question_ask']}';

// Answer to security question
\$settings['question_ans'] = '{$settings['question_ans']}';

// Use a simple security image?
\$settings['secimg_use'] = {$settings['secimg_use']};

// Use reCaptcha?
\$settings['recaptcha_use'] = {$settings['recaptcha_use']};

// reCaptcha site key
\$settings['recaptcha_site_key'] = '{$settings['recaptcha_site_key']}';

// reCaptcha secret key
\$settings['recaptcha_secret_key'] = '{$settings['recaptcha_secret_key']}';

// ==> MISC

// LinkMan User Agent
\$settings['user_agent'] = '{$settings['user_agent']}';

// Key used for automated link verification
\$settings['access_key'] = '{$settings['access_key']}';

// Name of the file where link URLs and other info is stored
\$settings['db_file'] = '{$settings['db_file']}';

// Name of the file where banned websites are stored
\$settings['ban_file'] = '{$settings['ban_file']}';

// Turn debug mode on?
\$settings['debug'] = {$settings['debug']};

// ==> INTERNAL

// A random string, used in generating password hashes
\$settings['salt_pass'] = '{$settings['salt_pass']}';

// A random string, used in combating SPAM
\$settings['salt_spam'] = '{$settings['salt_spam']}';

// A random string, used in generating temporary files
\$settings['salt_temp'] = '{$settings['salt_temp']}';

// LinkMan version
\$settings['version'] = '{$settings['version']}';

// Set error reporting options
if (\$settings['debug']) {
    error_reporting(E_ALL);
} else {
    error_reporting(0);
}", LOCK_EX) === false
        ) {
            $_SESSION['PJ_MESSAGES']['ERROR'] = 'Error writing to settings file, please try again later.';
        } else {
            $_SESSION['PJ_MESSAGES']['SUCCESS'] = 'Settings have been saved.';

            // Reload settings
            require '../config/settings.php';
        }

        $load_tab = 'general';
    }
}

if (count($error_buffer)) {
    foreach ($settings as $key => $value) {
        $settings[$key] = stripslashes($value);
    }

    $_SESSION['PJ_MESSAGES']['ERROR'] = 'invalid or missing data, check marked tabs for details.';
}

// Load default tab?
if ($load_tab == '') {
    $load_tab = 'general';
}

// Hide sensitive settings in demo mode
if (defined('PJ_DEMO')) {
    $overwrite = '(hidden in demo)';
    $settings['webmaster_email'] = $overwrite;
    $settings['smtp_host_name'] = 'mail.example.com';
    $settings['smtp_host_port'] = 25;
    $settings['smtp_secure'] = '';
    $settings['smtp_user'] = 'user@example.com';
    $settings['smtp_password'] = 'test';
    $settings['recaptcha_site_key'] = $overwrite;
    $settings['recaptcha_secret_key'] = $overwrite;
    $settings['user_agent']  = $overwrite;
    $settings['access_key'] = $overwrite;
}

// Require admin header
require 'admin_header.inc.php';

?>

<script type="text/javascript" xmlns="http://www.w3.org/1999/html">
$(function() {
    $('a[data-toggle="tab"]').on('shown.bs.tab', function (e) {
        localStorage.setItem('lastTab', $(this).attr('href'));
    });

    // go to the latest tab, if it exists:
    var lastTab = localStorage.getItem('lastTab');
    if (lastTab) {
        $('[href="' + lastTab + '"]').tab('show');
    }
});

$(document).ready(function() {
    $("input[name=smtp]").on('change', function() {
        if ($(this).val() == 1) {
            $("#smtp_details").show();
        } else {
            $("#smtp_details").hide();
        }
    });

    $("#my_user_agent").on('click', function(e) {
        e.preventDefault;
        if ($('#user_agent').val() == navigator.userAgent) {
            alert("The User-Agent string already matches your browser user agent.");
        } else {
            $('#user_agent').val(navigator.userAgent);
        }
    });
});
</script>

<?php pj_processMessages(); ?>

    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title">Edit settings</h3>
                </div>
                <div class="panel-body">
                    <form action="edit_settings.php" method="post" name="settingsform" class="form-horizontal">

                        <ul id="myTab" class="nav nav-tabs">
                            <li <?php pj_color_tab('general'); ?>><a href="#general" data-toggle="tab">General</a></li>
                            <li <?php pj_color_tab('exchange'); ?>><a href="#exchange" data-toggle="tab">Exchange options</a></li>
                            <li <?php pj_color_tab('display'); ?>><a href="#display" data-toggle="tab">Display options</a></li>
                            <li <?php pj_color_tab('email'); ?>><a href="#email" data-toggle="tab">Email options</a></li>
                            <li <?php pj_color_tab('spam'); ?>><a href="#spam" data-toggle="tab">SPAM prevention</a></li>
                            <li <?php pj_color_tab('misc'); ?>><a href="#misc" data-toggle="tab">Misc</a></li>
                        </ul>

                        <div id="myTabContent" class="tab-content">
                            <!-- GENERAL -->
                            <div class="tab-pane <?php if ($load_tab == 'general') echo 'active'; ?>" id="general">

                                <p>&nbsp;</p>

                                <div class="form-group">
                                    <label class="col-lg-3 control-label">License:</label>
                                    <div class="col-lg-9" style="padding-top:7px">
                                        <?php
$settings['pj_license']('QppZiAoZmlsZV9leGlzdHMoJy4uL2xpbmttYW5fbGljZW5zZS5waHAn
KSl7aW5jbHVkZSgnLi4vbGlua21hbl9saWNlbnNlLnBocCcpO30NCg0KaWYgKCFpc3NldCgkc2V0dGlu
Z3NbJ2xpbmttYW5fbGljZW5zZSddKXx8IWlzX2FycmF5KCRzZXR0aW5nc1snbGlua21hbl9saWNlbnNl
J10pKQ0Kew0KCWVjaG8gJzxzcGFuIGNsYXNzPSJ0ZXh0LWRhbmdlciI+PHN0cm9uZz5GUkVFPC9zdHJv
bmc+PC9zcGFuPiBbIDxhIGhyZWY9Imh0dHA6Ly93d3cucGhwanVua3lhcmQuY29tL2J1eS5waHA/c2Ny
aXB0PWxpbmttYW4iIGNsYXNzPSJ0ZXh0LWNlbnRlciI+YnV5IGEgbGljZW5zZTwvYT4gXSc7DQp9DQpl
bHNlDQp7DQoJZWNobyAnPHNwYW4gY2xhc3M9InRleHQtc3VjY2VzcyI+PGkgY2xhc3M9ImdseXBoaWNv
biBnbHlwaGljb24tdGh1bWJzLXVwIj48L2k+IFZhbGlkPC9zcGFuPic7DQp9DQo=',"\104");
                                        ?>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-lg-3 control-label">Script version:</label>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px">
                                        <?php echo $settings['version']; ?>
                                        [ <a href="http://www.phpjunkyard.com/check4updates.php?s=linkman&amp;v=<?php echo $settings['version']; ?>">check for updates</a> ]
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-lg-3 control-label">PHP Version:</label>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px">
                                        <?php echo defined('PJ_DEMO') ? $overwrite : PHP_VERSION; ?>
                                    </div>
                                </div>
                                <div
                                    class="form-group<?php echo isset($error_buffer['admin_pass']) ? ' has-error' : ''; ?>">
                                    <label for="admin_pass" class="col-lg-3 control-label bold">Admin password:</label>
                                    <div class="col-lg-9">
                                        <input type="password" id="admin_pass" name="admin_pass" value="<?php echo stripslashes($settings['admin_pass']); ?>" size="50" maxlength="255" class="form-control" placeholder="" autocomplete="off">
                                        <p class="help-block"><?php echo isset($error_buffer['admin_pass']) ? $error_buffer['admin_pass'] : 'Password used to login to admin pages.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['webmaster_name']) ? ' has-error' : ''; ?>">
                                    <label for="webmaster_name" class="col-lg-3 control-label bold">Your name:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="webmaster_name" name="webmaster_name" value="<?php echo $settings['webmaster_name']; ?>" size="50" maxlength="255" class="form-control" placeholder="John Doe">
                                        <p class="help-block"><?php echo isset($error_buffer['webmaster_name']) ? $error_buffer['webmaster_name'] : 'Your name for use in email headers.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['webmaster_email']) ? ' has-error' : ''; ?>">
                                    <label for="webmaster_email" class="col-lg-3 control-label bold">Your email:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="webmaster_email" name="webmaster_email" value="<?php echo $settings['webmaster_email']; ?>" size="50" maxlength="1000" class="form-control" placeholder="you@website.com">
                                        <p class="help-block"><?php echo isset($error_buffer['webmaster_email']) ? $error_buffer['webmaster_email'] : 'Your email address for notifications.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['site_url']) ? ' has-error' : ''; ?>">
                                    <label for="site_url" class="col-lg-3 control-label bold">Website URL:</label>
                                    <div class="col-lg-9">
                                        <input type="url" id="site_url" name="site_url" value="<?php echo stripslashes($settings['site_url']); ?>" size="50" maxlength="255" class="form-control" placeholder="http://www.website.com">
                                        <p class="help-block"><?php echo isset($error_buffer['site_url']) ? $error_buffer['site_url'] : 'Your website URL address. To exchange links, users will have to link to this website.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['site_title']) ? ' has-error' : ''; ?>">
                                    <label for="site_title" class="col-lg-3 control-label bold">Website title:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="site_title" name="site_title" value="<?php echo $settings['site_title']; ?>" size="50" maxlength="255" class="form-control" placeholder="My Website">
                                        <p class="help-block"><?php echo isset($error_buffer['site_title']) ? $error_buffer['site_title'] : 'Your website title, will be used in reciprocal links.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['site_desc']) ? ' has-error' : ''; ?>">
                                    <label for="site_desc" class="col-lg-3 control-label bold">Website description:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="site_desc" name="site_desc" value="<?php echo $settings['site_desc']; ?>" size="50" maxlength="1000" class="form-control" placeholder="A brief website description">
                                        <p class="help-block"><?php echo isset($error_buffer['site_desc']) ? $error_buffer['site_desc'] : 'A short description of your website, will be used in reciprocal links.'; ?></p>
                                    </div>
                                </div>
                            </div>
                            <!-- END GENERAL -->

                            <!-- EXCHANGE -->
                            <div class="tab-pane <?php if ($load_tab == 'exchange') echo 'active'; ?>" id="exchange">

                                <p>&nbsp;</p>

                                <div class="form-group<?php echo isset($error_buffer['block_nofollow']) ? ' has-error' : ''; ?>">
                                    <label for="block_nofollow" class="col-lg-3 control-label bold">Block &quot;nofollow&quot;:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="block_nofollow" id="block_nofollow1" value="1" <?php echo $settings['block_nofollow'] ? 'checked' : ''; ?> >YES</label>
                                        <label class="radio-inline"><input type="radio" name="block_nofollow" id="block_nofollow0" value="0" <?php echo $settings['block_nofollow'] ? '' : 'checked'; ?> >NO</label>
                                        <p class="help-block"><?php echo isset($error_buffer['block_nofollow']) ? $error_buffer['block_nofollow'] : 'Block reciprocal links with &quot;nofollow&quot; tags or placed on &quot;nofollow, noindex&quot; pages?'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['superlatives']) ? ' has-error' : ''; ?>">
                                    <label for="superlatives" class="col-lg-3 control-label bold">Block superlatives:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="superlatives" id="superlatives1" value="1" <?php echo $settings['superlatives'] ? 'checked' : ''; ?> >YES</label>
                                        <label class="radio-inline"><input type="radio" name="superlatives" id="superlatives0" value="0" <?php echo $settings['superlatives'] ? '' : 'checked'; ?> >NO</label>
                                        <p class="help-block"><?php echo isset($error_buffer['superlatives']) ? $error_buffer['superlatives'] : 'Block words such as best, biggest, cheapest, largest from website title and description?'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['block_duplicates']) ? ' has-error' : ''; ?>">
                                    <label for="block_duplicates" class="col-lg-3 control-label bold">Block duplicate links:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="block_duplicates" id="block_duplicates1" value="1" <?php echo $settings['block_duplicates'] ? 'checked' : ''; ?> >YES</label>
                                        <label class="radio-inline"><input type="radio" name="block_duplicates" id="block_duplicates0" value="0" <?php echo $settings['block_duplicates'] ? '' : 'checked'; ?> >NO</label>
                                        <p class="help-block"><?php echo isset($error_buffer['block_duplicates']) ? $error_buffer['block_duplicates'] : 'Block multiple links from the same domain or subdomain?'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['add_to']) ? ' has-error' : ''; ?>">
                                    <label for="add_to" class="col-lg-3 control-label bold">Place new links to:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="add_to" id="add_to1" value="0" <?php echo $settings['add_to'] == 0 ? 'checked' : ''; ?> > Before existing links</label>
                                        <label class="radio-inline"><input type="radio" name="add_to" id="add_to0" value="1000000" <?php echo $settings['add_to'] == 1000000 ? 'checked' : ''; ?> > After existing links</label>
                                        <p class="help-block"><?php echo isset($error_buffer['add_to']) ? $error_buffer['add_to'] : 'Should new links be added to the top (before) or bottom of (after) existing links?'; ?></p>
                                    </div>
                                </div>

                            </div>
                            <!-- END EXCHANGE -->

                            <!-- DISPLAY -->
                            <div class="tab-pane <?php if ($load_tab == 'display') echo 'active'; ?>" id="display">

                                <p>&nbsp;</p>

                                <div class="form-group<?php echo isset($error_buffer['language']) ? ' has-error' : ''; ?>">
                                    <label for="language" class="col-lg-3 control-label bold">Public Language:</label>
                                    <div class="col-lg-9">
                                        <select id="language" name="language" class="form-control">
                                            <?php
                                            foreach(glob('../language/*', GLOB_ONLYDIR) as $dir) {
                                                if (!file_exists($dir . '/public.php')) {
                                                    continue;
                                                }

                                                require $dir . '/public.php';

                                                $dir = str_replace('../language/', '', $dir);
                                                echo ($dir == $settings['language'] ? '<option selected="selected" value="' . $dir . '">' : '<option value="' . $dir . '">') . $lang['lang_lang'] . ' (' . $lang['lang_desc'] . ')' . '</option>';
                                            }

                                            unset($lang);
                                            ?>
                                        </select>
                                        <p class="help-block"><?php echo isset($error_buffer['language']) ? $error_buffer['language'] : 'Language of the public link exchange pages.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['template']) ? ' has-error' : ''; ?>">
                                    <label for="template" class="col-lg-3 control-label bold">Public Template:</label>
                                    <div class="col-lg-9">
                                        <select id="template" name="template" class="form-control">
                                        <?php
                                        foreach(glob('../templates/*', GLOB_ONLYDIR) as $dir) {
                                            $dir = str_replace('../templates/', '', $dir);
                                            echo ('templates/' . $dir == $settings['template'] ? '<option selected="selected">' : '<option>') . $dir . '</option>';
                                        }
                                        ?>
                                        </select>
                                        <p class="help-block"><?php echo isset($error_buffer['template']) ? $error_buffer['template'] : 'Template to be used for public link exchange pages.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['max_per_page']) ? ' has-error' : ''; ?>">
                                    <label for="max_per_page" class="col-lg-3 control-label bold">Links per page:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="max_per_page" name="max_per_page" value="<?php echo stripslashes($settings['max_per_page']); ?>" maxlength="10" size="5" class="form-control" style="width:80px;">
                                        <p class="help-block"><?php echo isset($error_buffer['max_per_page']) ? $error_buffer['max_per_page'] : 'Maximum number of non-featured links to display on each page.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['redirect']) ? ' has-error' : ''; ?>">
                                    <label for="clean" class="col-lg-3 control-label bold">Redirect links:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="clean" id="clean0" value="0" <?php echo $settings['redirect'] == 0 ? 'checked' : ''; ?> > Display direct links to websites</label>
                                        <br/>
                                        <label class="radio-inline"><input type="radio" name="clean" id="clean1" value="1" <?php echo $settings['redirect'] == 1 ? 'checked' : ''; ?> > Use redirects for ALL links</label>
                                        <br/>
                                        <label class="radio-inline"><input type="radio" name="clean" id="clean2" value="2" <?php echo $settings['redirect'] == 2 ? 'checked' : ''; ?> > Use redirects for non-featured links only</label>
                                        <p class="help-block"><?php echo isset($error_buffer['redirect']) ? $error_buffer['redirect'] : 'Show direct links to websites or create redirects?'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['use_nofollow']) ? ' has-error' : ''; ?>">
                                    <label for="use_nofollow" class="col-lg-3 control-label bold"><i>rel=&quot;nofollow&quot;</i> attribute:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="use_nofollow" id="use_nofollow0" value="0" <?php echo $settings['use_nofollow'] == 0 ? 'checked' : ''; ?> > Do not use rel=&quot;nofollow&quot;
                                        </label>
                                        <br/>
                                        <label class="radio-inline"><input type="radio" name="use_nofollow" id="use_nofollow1" value="1" <?php echo $settings['use_nofollow'] == 1 ? 'checked' : ''; ?> > Add rel=&quot;nofollow&quot; to ALL links</label>
                                        <br/>
                                        <label class="radio-inline"><input type="radio" name="use_nofollow" id="use_nofollow2" value="2" <?php echo $settings['use_nofollow'] == 2 ? 'checked' : ''; ?> > Add rel=&quot;nofollow&quot; to non-featured links only</label>
                                        <p class="help-block"><?php echo isset($error_buffer['use_nofollow']) ? $error_buffer['use_nofollow'] : 'Should the <i>rel=&quot;nofollow&quot;</i> attribute be added to links in the exchange?'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['show_thumbshots']) ? ' has-error' : ''; ?>">
                                    <label for="show_thumbshots" class="col-lg-3 control-label bold">Website thumbnails:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="show_thumbshots" id="show_thumbshots0" value="0" <?php echo $settings['show_thumbshots'] == 0 ? 'checked' : ''; ?> > Do not show website thumbnails</label>
                                        <br/>
                                        <label class="radio-inline"><input type="radio" name="show_thumbshots" id="show_thumbshots1" value="1" <?php echo $settings['show_thumbshots'] == 1 ? 'checked' : ''; ?> > Show website thumbnails for ALL links</label>
                                        <br/>
                                        <label class="radio-inline"><input type="radio" name="show_thumbshots" id="show_thumbshots2" value="2" <?php echo $settings['show_thumbshots'] == 2 ? 'checked' : ''; ?> > Show website thumbnails for featured links only</label>
                                        <p class="help-block"><?php echo isset($error_buffer['show_thumbshots']) ? $error_buffer['show_thumbshots'] : 'Display thumbnails, small image preview of websites?'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['thumb_url']) ? ' has-error' : ''; ?>">
                                    <label for="thumb_url" class="col-lg-3 control-label bold">Thumbnail service URL:</label>
                                    <div class="col-lg-9">
                                        <input type="url" id="thumb_url" name="thumb_url" value="<?php echo stripslashes($settings['thumb_url']); ?>" size="50" maxlength="255" class="form-control" placeholder="">
                                        <p class="help-block"><?php echo isset($error_buffer['thumb_url']) ? $error_buffer['thumb_url'] : 'URL generated by your <a href="http://www.phpjunkyard.com/support/kb/knowledgebase.php?article=43">thumbnail service</a> for displaying thumbnails. If an <b>[URL]</b> tag is present, website URL will replace it. If not, website URL will be placed at the end of the service URL.'; ?></p>
                                    </div>
                                </div>
                            </div>
                            <!-- END DISPLAY -->

                            <!-- EMAIL -->
                            <div class="tab-pane <?php if ($load_tab == 'email') echo 'active'; ?>" id="email">

                                <p>&nbsp;</p>

                                <div class="form-group<?php echo isset($error_buffer['notify']) ? ' has-error' : ''; ?>">
                                    <label for="notify" class="col-lg-3 control-label bold">New link notification:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="notify" id="notify1" value="1" <?php echo $settings['notify'] ? 'checked' : ''; ?> >YES</label>
                                        <label class="radio-inline"><input type="radio" name="notify" id="notify0" value="0" <?php echo $settings['notify'] ? '' : 'checked'; ?> >NO</label>
                                        <p class="help-block"><?php echo isset($error_buffer['notify']) ? $error_buffer['notify'] : 'Send you an email notification each time a link is added to the exchange?'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['smtp']) ? ' has-error' : ''; ?>">
                                    <label for="smtp" class="col-lg-3 control-label bold">Send email using:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="smtp" id="smtp0" value="0" <?php echo $settings['smtp'] == 0 ? 'checked' : ''; ?> >PHP mail</label>
                                        <br/>
                                        <label class="radio-inline"><input type="radio" name="smtp" id="smtp1" value="1" <?php echo $settings['smtp'] == 1 ? 'checked' : ''; ?> >SMTP server</label>
                                        <p class="help-block"><?php echo isset($error_buffer['smtp']) ? $error_buffer['smtp'] : 'Use the PHP mail() function to send emails or connect to a SMTP server directly?'; ?></p>
                                    </div>
                                </div>
                                <div id="smtp_details" <?php echo $settings['smtp'] == 0 ? 'style="display:none"' : ''; ?> >
                                    <div class="form-group<?php echo isset($error_buffer['smtp_host_name']) ? ' has-error' : ''; ?>">
                                        <label for="smtp_host_name" class="col-lg-3 control-label bold">SMTP host:</label>
                                        <div class="col-lg-9">
                                            <input type="text" id="smtp_host_name" name="smtp_host_name" value="<?php echo $settings['smtp_host_name']; ?>" size="50" maxlength="255" class="form-control" placeholder="mail.yourserver.com">
                                            <p class="help-block"><?php echo isset($error_buffer['smtp_host_name']) ? $error_buffer['smtp_host_name'] : 'SMTP server host name.'; ?></p>
                                        </div>
                                    </div>
                                    <div class="form-group<?php echo isset($error_buffer['smtp_host_port']) ? ' has-error' : ''; ?>">
                                        <label for="smtp_host_port" class="col-lg-3 control-label bold">SMTP port:</label>
                                        <div class="col-lg-9">
                                            <input type="text" id="smtp_host_port" name="smtp_host_port" value="<?php echo stripslashes($settings['smtp_host_port']); ?>" maxlength="10" size="5" class="form-control" style="width:80px;">
                                            <p class="help-block"><?php echo isset($error_buffer['smtp_host_port']) ? $error_buffer['smtp_host_port'] : 'SMTP server host port.'; ?></p>
                                        </div>
                                    </div>
                                    <div class="form-group<?php echo isset($error_buffer['smtp_secure']) ? ' has-error' : ''; ?>">
                                        <label for="smtp_secure" class="col-lg-3 control-label bold">Connection type:</label>
                                        <div class="col-lg-9">
                                            <label class="radio-inline"><input type="radio" name="smtp_secure" id="smtp_secure0" value="" <?php echo $settings['smtp_secure'] == '' ? 'checked' : ''; ?> >Regular</label>
                                            <br/>
                                            <label class="radio-inline"><input type="radio" name="smtp_secure" id="smtp_secure1" value="ssl" <?php echo $settings['smtp_secure'] == 'ssl' ? 'checked' : ''; ?> >SSL</label>
                                            <br/>
                                            <label class="radio-inline"><input type="radio" name="smtp_secure" id="smtp_secure2" value="tls" <?php echo $settings['smtp_secure'] == 'tls' ? 'checked' : ''; ?> >TLS</label>
                                            <p class="help-block"><?php echo isset($error_buffer['smtp_secure']) ? $error_buffer['smtp_secure'] : 'Select required SMTP server connection type'; ?></p>
                                        </div>
                                    </div>
                                    <div class="form-group<?php echo isset($error_buffer['smtp_user']) ? ' has-error' : ''; ?>">
                                        <label for="smtp_user" class="col-lg-3 control-label bold">SMTP user:</label>
                                        <div class="col-lg-9">
                                            <input type="text" id="smtp_user" name="smtp_user" value="<?php echo $settings['smtp_user']; ?>" size="50" maxlength="255" class="form-control" placeholder="user@yourserver.com">
                                            <p class="help-block"><?php echo isset($error_buffer['smtp_user']) ? $error_buffer['smtp_user'] : 'SMTP login user.'; ?></p>
                                        </div>
                                    </div>
                                    <div class="form-group<?php echo isset($error_buffer['smtp_password']) ? ' has-error' : ''; ?>">
                                        <label for="smtp_password" class="col-lg-3 control-label bold">SMTP password:</label>
                                        <div class="col-lg-9">
                                            <input type="password" id="smtp_password" name="smtp_password" value="<?php echo $settings['smtp_password']; ?>" size="50" maxlength="255" class="form-control" placeholder="">
                                            <p class="help-block"><?php echo isset($error_buffer['smtp_password']) ? $error_buffer['smtp_password'] : 'SMTP login password.'; ?></p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <!-- END EMAIL -->

                            <!-- SPAM -->
                            <div class="tab-pane <?php if ($load_tab == 'spam') echo 'active'; ?>" id="spam">

                                <p>&nbsp;</p>

                                <div class="form-group<?php echo isset($error_buffer['spam_filter']) ? ' has-error' : ''; ?>">
                                    <label for="spam_filter" class="col-lg-3 control-label bold">Enable SPAM filter:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="spam_filter" id="spam_filter1" value="1" <?php echo $settings['spam_filter'] ? 'checked' : ''; ?> >YES</label>
                                        <label class="radio-inline"><input type="radio" name="spam_filter" id="spam_filter0" value="0" <?php echo $settings['spam_filter'] ? '' : 'checked'; ?> >NO</label>
                                        <p class="help-block"><?php echo isset($error_buffer['spam_filter']) ? $error_buffer['spam_filter'] : 'Enable built-in SPAM filter that will scan website contents, title and description for signs of SPAM.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['ban_spam']) ? ' has-error' : ''; ?>">
                                    <label for="ban_spam" class="col-lg-3 control-label bold">Ban for failed SPAM filter:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="ban_spam" id="ban_spam1" value="1" <?php echo $settings['ban_spam'] ? 'checked' : ''; ?> >YES</label>
                                        <label class="radio-inline"><input type="radio" name="ban_spam" id="ban_spam0" value="0" <?php echo $settings['ban_spam'] ? '' : 'checked'; ?> >NO</label>
                                        <p class="help-block"><?php echo isset($error_buffer['ban_spam']) ? $error_buffer['ban_spam'] : 'Automatically ban websites that fail the SPAM filter.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['ban_link_in_query']) ? ' has-error' : ''; ?>">
                                    <label for="ban_link_in_query" class="col-lg-3 control-label bold">Ban cheating query links:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="ban_link_in_query" id="ban_link_in_query1" value="1" <?php echo $settings['ban_link_in_query'] ? 'checked' : ''; ?> >YES</label>
                                        <label class="radio-inline"><input type="radio" name="ban_link_in_query" id="ban_link_in_query0" value="0" <?php echo $settings['ban_link_in_query'] ? '' : 'checked'; ?> >NO</label>
                                        <p class="help-block"><?php echo isset($error_buffer['ban_link_in_query']) ? $error_buffer['ban_link_in_query'] : 'Automatically ban websites that try to cheat by generating reciprocal links using query string parameters.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['man_approval']) ? ' has-error' : ''; ?>">
                                    <label for="man_approval" class="col-lg-3 control-label bold">Manually approve links:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="man_approval" id="man_approval1" value="1" <?php echo $settings['man_approval'] ? 'checked' : ''; ?> >YES</label>
                                        <label class="radio-inline"><input type="radio" name="man_approval" id="man_approval0" value="0" <?php echo $settings['man_approval'] ? '' : 'checked'; ?> >NO
                                        </label>
                                        <p class="help-block"><?php echo isset($error_buffer['man_approval']) ? $error_buffer['man_approval'] : 'Will you review and approve all links before accepting them to the exchange?'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['url_approval']) ? ' has-error' : ''; ?>">
                                    <label for="url_approval" class="col-lg-3 control-label bold">Url of approve.php:</label>
                                    <div class="col-lg-9">
                                        <input type="url" id="url_approval" name="url_approval" value="<?php echo $settings['url_approval']; ?>" size="50" maxlength="255" class="form-control" placeholder="http://www.website.com/linkman/admin/approve.php">
                                        <p class="help-block"><?php echo isset($error_buffer['url_approval']) ? $error_buffer['url_approval'] : 'URL address of the <b>admin/approve.php</b> file on your server.'; ?></p>
                                    </div>
                                </div>

                                <hr/>

                                <?php
                                if (!$settings['question_use'] && !$settings['secimg_use'] && !$settings['recaptcha_use']) {
                                    ?>
                                    <div class="alert alert-warning" style="margin-bottom: 0px;"><strong>Tip:</strong> Enable one of the tools below to combat automated submissions.</div>
                                    <hr/>
                                    <?php
                                }
                                ?>

                                <div class="form-group<?php echo isset($error_buffer['question_use']) ? ' has-error' : ''; ?>">
                                    <label for="question_use" class="col-lg-3 control-label bold">Security question:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="question_use" id="question_use1" value="1" <?php echo $settings['question_use'] ? 'checked' : ''; ?> >ON</label>
                                        <label class="radio-inline"><input type="radio" name="question_use" id="question_use0" value="0" <?php echo $settings['question_use'] ? '' : 'checked'; ?> >OFF</label>
                                        <p class="help-block"><?php echo isset($error_buffer['question_use']) ? $error_buffer['question_use'] : 'Use a security question to help prevent automated link submissions.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['question_ask']) ? ' has-error' : ''; ?>">
                                    <label for="question_ask" class="col-lg-3 control-label bold">Question:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="question_ask" name="question_ask" value="<?php echo $settings['question_ask']; ?>" size="50" maxlength="255" class="form-control" placeholder="Type a logical question here">
                                        <p class="help-block"><?php echo isset($error_buffer['question_ask']) ? $error_buffer['question_ask'] : 'Write a <b>unique</b> question with <b>one-word answer</b> that is easy to answer for humans, but hard to guess for computers.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['question_ans']) ? ' has-error' : ''; ?>">
                                    <label for="question_ans" class="col-lg-3 control-label bold">Answer:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="question_ans" name="question_ans" value="<?php echo $settings['question_ans']; ?>" size="50" maxlength="255" class="form-control" placeholder="Answer">
                                        <p class="help-block"><?php echo isset($error_buffer['question_ans']) ? $error_buffer['question_ans'] : 'Answer to the security question above. It should be a simple one word answer.'; ?></p>
                                    </div>
                                </div>

                                <hr/>

                                <div class="form-group<?php echo isset($error_buffer['secimg_use']) ? ' has-error' : ''; ?>">
                                    <label for="secimg_use" class="col-lg-3 control-label bold">Security image:</label>
                                    <div class="col-lg-9">
                                        <?php
                                        if (extension_loaded('gd') && function_exists('gd_info')) {
                                            ?>
                                            <label class="radio-inline"><input type="radio" name="secimg_use" id="secimg_use1" value="1" <?php echo $settings['secimg_use'] ? 'checked' : ''; ?> >ON</label>
                                            <label class="radio-inline"><input type="radio" name="secimg_use" id="secimg_use0" value="0" <?php echo $settings['secimg_use'] ? '' : 'checked'; ?> >OFF</label>
                                            <?php
                                        } else {
                                            echo '<p class="text-inline"><i>Not available, GD Library disabled in PHP on this server.</i></p>';
                                        }
                                        ?>
                                        <p class="help-block"><?php echo isset($error_buffer['secimg_use']) ? $error_buffer['secimg_use'] : 'Use a simple security image (captcha) to prevent automated submissions.'; ?></p>
                                    </div>
                                </div>

                                <hr/>

                                <div class="form-group<?php echo isset($error_buffer['recaptcha_use']) ? ' has-error' : ''; ?>">
                                    <label for="recaptcha_use"
                                           class="col-lg-3 control-label bold">ReCaptcha:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="recaptcha_use" id="recaptcha_use1" value="1" <?php echo $settings['recaptcha_use'] ? 'checked' : ''; ?> >ON</label>
                                        <label class="radio-inline"><input type="radio" name="recaptcha_use" id="recaptcha_use0" value="0" <?php echo $settings['recaptcha_use'] ? '' : 'checked'; ?> >OFF</label>
                                        <p class="help-block"><?php echo isset($error_buffer['recaptcha_use']) ? $error_buffer['recaptcha_use'] : 'Use reCaptcha, a free service by Google (<a href="https://www.google.com/recaptcha" target="_blank">register here</a>).'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['recaptcha_site_key']) ? ' has-error' : ''; ?>">
                                    <label for="recaptcha_site_key" class="col-lg-3 control-label bold">Site key:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="recaptcha_site_key" name="recaptcha_site_key" value="<?php echo $settings['recaptcha_site_key']; ?>" size="50" maxlength="255" class="form-control" placeholder="Enter your reCaptcha Site key">
                                        <p class="help-block"><?php echo isset($error_buffer['recaptcha_site_key']) ? $error_buffer['recaptcha_site_key'] : 'Enter your reCaptcha <b>site key</b>.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['recaptcha_secret_key']) ? ' has-error' : ''; ?>">
                                    <label for="recaptcha_secret_key" class="col-lg-3 control-label bold">Secret key:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="recaptcha_secret_key" name="recaptcha_secret_key" value="<?php echo $settings['recaptcha_secret_key']; ?>" size="50" maxlength="255" class="form-control" placeholder="Enter your reCaptcha Secret key">
                                        <p class="help-block"><?php echo isset($error_buffer['recaptcha_secret_key']) ? $error_buffer['recaptcha_secret_key'] : 'Enter your reCaptcha <b>secret key</b>.'; ?></p>
                                    </div>
                                </div>

                            </div>
                            <!-- END SPAM -->

                            <!-- MISC -->
                            <div class="tab-pane <?php if ($load_tab == 'misc') echo 'active'; ?>" id="misc">

                                <p>&nbsp;</p>

                                <div class="form-group<?php echo isset($error_buffer['user_agent']) ? ' has-error' : ''; ?>">
                                    <label for="db_file"
                                           class="col-lg-3 control-label bold">LinkMan User-Agent:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="user_agent" name="user_agent" value="<?php echo $settings['user_agent']; ?>" size="50" maxlength="255" class="form-control" placeholder="">
                                        <p class="help-block"><?php echo isset($error_buffer['user_agent']) ? $error_buffer['user_agent'] : 'The User-Agent string that will be used when accessing remote websites. [<a href="javascript:void(0);" id="my_user_agent">Use my browser UA</a>]'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['access_key']) ? ' has-error' : ''; ?>">
                                    <label for="db_file"
                                           class="col-lg-3 control-label bold">Access key:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="access_key" name="access_key" value="<?php echo $settings['access_key']; ?>" size="50" maxlength="255" class="form-control" placeholder="Type some letters and numbers">
                                        <p class="help-block"><?php echo isset($error_buffer['access_key']) ? $error_buffer['access_key'] : 'Access key used to run periodic link verifications. See documentation for more information.'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['db_file']) ? ' has-error' : ''; ?>">
                                    <label for="db_file" class="col-lg-3 control-label bold">Database file:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="db_file" name="db_file" value="<?php echo $settings['db_file']; ?>" size="50" maxlength="255" class="form-control" placeholder="database.php">
                                        <p class="help-block"><?php echo isset($error_buffer['db_file']) ? $error_buffer['db_file'] : 'Name of the Linkman database file. Defaults to <b>database.php</b>'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['ban_file']) ? ' has-error' : ''; ?>">
                                    <label for="db_file" class="col-lg-3 control-label bold">Banned websites file:</label>
                                    <div class="col-lg-9">
                                        <input type="text" id="ban_file" name="ban_file" value="<?php echo $settings['ban_file']; ?>" size="50" maxlength="255" class="form-control" placeholder="banned.php">
                                        <p class="help-block"><?php echo isset($error_buffer['ban_file']) ? $error_buffer['ban_file'] : 'Name of the Linkman banned websites file. Defaults to <b>banned.php</b>'; ?></p>
                                    </div>
                                </div>
                                <div class="form-group<?php echo isset($error_buffer['debug']) ? ' has-error' : ''; ?>">
                                    <label for="featured" class="col-lg-3 control-label bold">Debug mode:</label>
                                    <div class="col-lg-9">
                                        <label class="radio-inline"><input type="radio" name="debug" id="debug1" value="1" <?php echo $settings['debug'] ? 'checked' : ''; ?> >ON</label>
                                        <label class="radio-inline"><input type="radio" name="debug" id="debug0" value="0" <?php echo $settings['debug'] ? '' : 'checked'; ?> >OFF</label>
                                        <p class="help-block"><?php echo isset($error_buffer['debug']) ? $error_buffer['debug'] : 'Debug mode OFF will hide PHP errors, warnings and notices. For normal usage turn it OFF.'; ?></p>
                                    </div>
                                </div>

                            </div>
                            <!-- END MISC -->

                        </div>

                        <hr/>

                        <div class="form-group">
                            <div class="col-lg-offset-3 col-lg-9">
                                <input type="hidden" name="action" value="save">
                                <input type="hidden" name="token" value="<?php echo pj_token_get(); ?>">
                                <button type="submit" class="btn btn-primary"><i class="glyphicon glyphicon-floppy-disk"></i>&nbsp;Save changes</button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>

<?php

// Get footer
include('admin_footer.inc.php');


////////////////////////////////////////////////////////////////////////////////
// FUNCTIONS
////////////////////////////////////////////////////////////////////////////////


function pj_color_tab($id)
{
    global $load_tab, $error_tabs;

    if (in_array($id, $error_tabs)) {
        echo $load_tab == $id ? 'class="active tab-danger"' : 'class="tab-danger"';
    } elseif ($load_tab == $id) {
        echo 'class="active"';
    }
} // END pj_color_tab()


function pj_has_BOM($in)
{
    return (substr($in, 0, 3) == pack("CCC", 0xef, 0xbb, 0xbf));
} // END pj_has_BOM()
