<?php
/*
 * This file is part of LinkMan - PHP Links Manager.
 *
 * (c) Copyright 2016 by Klemen Stirn. All rights reserved.
 * http://www.phpjunkyard.com
 * http://www.phpjunkyard.com/php-link-manager.php
 *
 * For the full copyright and license agreement information, please view
 * the docs/index.html file that was distributed with this source code.
 */

// Check if this is a valid include
if (!defined('IN_SCRIPT')) {
    die('Invalid attempt');
}


////////////////////////////////////////////////////////////////////////////////
// FUNCTIONS
////////////////////////////////////////////////////////////////////////////////


function pj_get_tmp_array($file_key, $extension = '.php')
{
    // Return demo data?
    if ($file_key == 'demo') {
        return array (
            '{NAME}' => 'John Doe',
            '{EMAIL}' => 'john@example.com',
            '{URL}' => 'http://www.example.com',
            '{RECURL}' => 'http://www.example.com/links',
            '{TITLE}' => 'A sample pending website',
            '{DESCRIPTION}' => 'This is a website pending approval from the admin...',
        );
    }
    
    // Read the file and unserialize it
    $data = explode('//', file_get_contents('../tmp/' . $file_key . $extension), 2);

    // Convert contents into an array
    if (isset($data[1])) {
        return unserialize($data[1]);
    }

    die('Invalid tmp file');

} // END pj_get_tmp_array()


function reciprocal_link_found($html)
{
    global $settings;

    // Convert all code to lowercase
    $html = strtolower($html);

    // Remove "https" and "www" for verification purposes
    $site_url = str_replace(array('https://', 'http://www.'), array('http://', 'http://'), strtolower($settings['site_url']));
    $site_url = trim($site_url, '/');

    // Can we find the reciprocal link?
    if (preg_match_all('/<a\s[^>]*href=([\"\']??)([^" >]*?)\\1([^>]*)>/siU', $html, $matches, PREG_SET_ORDER)) {
        foreach ($matches as $match) {
            $match[2] = str_replace(array('https://', 'http://www.'), array('http://', 'http://'), $match[2]);

            if (trim($match[2], '/') == $site_url) {
                // Link found, check for nofollow
                if ($settings['block_nofollow']) {
                    // Check for nofollow tag in link
                    if (strstr($match[3], 'nofollow')) {
                        return 'NOFOLLOW';
                    }

                    // Check for nofollow tag in page head
                    if (preg_match('/<meta([^>]+)(noindex|nofollow)(.*)>/siU', $html, $meta)) {
                        return 'NOFOLLOW';
                    }
                }

                // All OK
                return true;
            }
        }
    }

    // No reciprocal link found
    return false;

} // END reciprocal_link_found()


function link_verify_error($id, $error, $delete=true)
{
    global $database, $data_modified, $access_key;

    echo 'ERROR: ' . $error . "\n";

    if ($delete) {
        unset($database[$id]);
        $data_modified = true;
        echo "*** Link will be deleted ***\n";
    } else {
        $email = $access_key ? '<' . $database[$id]['E'] . '>' : '&lt;' . $database[$id]['E'] . '&gt;';
        echo "OWNER: {$database[$id]['N']} {$email}\nIGNORING\n";
    }

} // END link_verify_error()


function crawl_website($url)
{
    global $settings;

    // Use cURL if possible
    if (function_exists('curl_init')) {
        $ch = curl_init();

        $options = array(
            CURLOPT_URL => $url,
            CURLOPT_HEADER => false,
            CURLOPT_RETURNTRANSFER => true,
            //CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_MAXREDIRS => 3,
            CURLOPT_TIMEOUT => 20,
            CURLOPT_SSL_VERIFYHOST => false,
            CURLOPT_SSL_VERIFYPEER => false,
            CURLOPT_USERAGENT => $settings['user_agent'],
            CURLOPT_HTTPHEADER => array('Connection: close', 'Cache-Control: no-cache'),
        );

        curl_setopt_array($ch, $options);

        $result = curl_exec($ch);
    } // No cURL, try with another PHP function
    else {
        $result = @file_get_contents($url);
    }

    // Did we succeed?
    if ($result === false || strlen($result) < 1) {
        return false;
    } else {
        return $result;
    }

} // END crawl_website()
