<?php
/*
 * This file is part of LinkMan - PHP Links Manager.
 *
 * (c) Copyright 2016 by Klemen Stirn. All rights reserved.
 * http://www.phpjunkyard.com
 * http://www.phpjunkyard.com/php-link-manager.php
 *
 * For the full copyright and license agreement information, please view
 * the docs/index.html file that was distributed with this source code.
 */

define('IN_SCRIPT', 1);
define('THIS_PAGE', 'INDEX');
define('INSTALL', 1);
define('REQUIRE_PHP_VERSION','5.3.0');

// Require the settings file
require '../config/settings.php';

// Load functions
require '../inc/common.inc.php';

// Start session
pj_session_start();

// We will use this later...
$settings['SESSION_OK'] = false;
$settings['INSTALL_OK'] = false;
$error_buffer = array();

// Start tests
// ==> PHP Version
if ( function_exists('version_compare') && version_compare(PHP_VERSION,REQUIRE_PHP_VERSION,'<') ) {
    $error_buffer['PHP_VERSION'] = 1;
}

// ==> Settings file
if (!is_writable('../config/settings.php')) {
    $error_buffer['SETTINGS'] = 1;
}

// ==> Database file
if (!file_exists('../config/' . $settings['db_file'])) {
    $error_buffer['DATABASE'] = 0;
} elseif (!is_writable('../config/' . $settings['db_file'])) {
    $error_buffer['DATABASE'] = 1;
}

// ==> Banned file
if (!file_exists('../config/' . $settings['ban_file'])) {
    $error_buffer['BAN'] = 0;
} elseif (!is_writable('../config/' . $settings['ban_file'])) {
    $error_buffer['BAN'] = 1;
}

// ==> tmp folder
if (!is_dir('../tmp')) {
    $error_buffer['TMP'] = 0;
} elseif (!is_writable('../tmp')) {
    $error_buffer['TMP'] = 1;
}

// Is this a POST?
if (pj_POST('action') == 'save') {
    // Test PHP sessions
    if (isset($_SESSION['TEST']) && $_SESSION['TEST'] == 1) {
        $settings['SESSION_OK'] = true;
    } else {
        $error_buffer['SESSION'] = '<b>Session Failed</b><br />Contact your hosting company to verify why PHP Sessions aren\'t working.';
    }

    // Admin password
    $settings['admin_pass'] = pj_input(pj_POST('admin_pass')) or $error_buffer['admin_pass'] = 'Choose a password you will use to access admin pages.';

    // Detect approve.php URL
    if (isset($_SERVER['HTTP_HOST']) && isset($_SERVER['REQUEST_URI']) && strpos($_SERVER['REQUEST_URI'], '/install/index.php') !== false) {
        $settings['url_approval'] = 'http://' . $_SERVER['HTTP_HOST'] . str_replace('/install/index.php', '/admin/approve.php', $_SERVER['REQUEST_URI']);
    }

    // Remove "templates/" from the template settings
    $settings['template'] = str_replace('templates/', '', $settings['template']);

    // Get the user agent
    $settings['user_agent'] = isset($_SERVER['HTTP_USER_AGENT']) ? pj_input($_SERVER['HTTP_USER_AGENT']) : $settings['user_agent'];

    // Generate other required strings
    $settings['access_key'] = pj_random_salt(20, true);
    $settings['salt_pass']  = pj_random_salt();
    $settings['salt_spam']  = pj_random_salt();
    $settings['salt_temp']  = pj_random_salt();

    // Add slashes to settings before saving
    $settings = array_map("addslashes", $settings);

    // If no errors save settings
    if (count($error_buffer) == 0) {
        // Update settings file
        if (@file_put_contents('../config/settings.php', "<?php
if (!defined('IN_SCRIPT')) {
    die('Invalid attempt!');
}

// ==> GENERAL

// Admin password
\$settings['admin_pass'] = '{$settings['admin_pass']}';

// Webmaster name
\$settings['webmaster_name'] = '{$settings['webmaster_name']}';

// Webmaster email
\$settings['webmaster_email'] = '{$settings['webmaster_email']}';

// Website URL
\$settings['site_url'] = '{$settings['site_url']}';

// Website title
\$settings['site_title'] = '{$settings['site_title']}';

// Website description
\$settings['site_desc'] = '{$settings['site_desc']}';

// ==> EXCHANGE OPTIONS

// Block links with \"nofollow\" attribute
\$settings['block_nofollow'] = {$settings['block_nofollow']};

// Block words like best, biggest, largest
\$settings['superlatives'] = {$settings['superlatives']};

// Block duplicate links
\$settings['block_duplicates'] = {$settings['block_duplicates']};

// Where to add new links? 0 = top of list, 1000000 = end of list
\$settings['add_to'] = {$settings['add_to']};

// ==> DISPLAY OPTIONS

// Public language
\$settings['language'] = '{$settings['language']}';

// Public template
\$settings['template'] = 'templates/{$settings['template']}';

// Number of links per page
\$settings['max_per_page'] = {$settings['max_per_page']};

// Use normal links? 0=NORMAL, 1=REDIRECT ALL, 2=REDIRECT RECIPROCAL ONLY
\$settings['redirect'] = {$settings['redirect']};

// Add rel=\"nofollow\" attribute to links? 0=NO, 1=YES, 2=FOR RECIPROCAL ONLY
\$settings['use_nofollow'] = {$settings['use_nofollow']};

// Display website thumbnails? 0=NO, 1=YES, 2=FEATURED LINKS ONLY
\$settings['show_thumbshots'] = {$settings['show_thumbshots']};

// Thumbnails service URL
\$settings['thumb_url'] = '{$settings['thumb_url']}';

// ==> EMAIL OPTIONS

// Send email notification of new links?
\$settings['notify'] = {$settings['notify']};

// Use SMTP to send emails?
\$settings['smtp'] = {$settings['smtp']};

// SMTP host
\$settings['smtp_host_name'] = '{$settings['smtp_host_name']}';

// SMTP port
\$settings['smtp_host_port'] = {$settings['smtp_host_port']};

// SMTP connection type: 'tls' or 'ssl' or empty
\$settings['smtp_secure'] = '{$settings['smtp_secure']}';

// SMTP username
\$settings['smtp_user'] = '{$settings['smtp_user']}';

// SMTP password
\$settings['smtp_password'] = '{$settings['smtp_password']}';

// ==> SPAM PREVENTION

// Enable SPAM filter?
\$settings['spam_filter'] = {$settings['spam_filter']};

// Ban websites that fail the SPAM filter?
\$settings['ban_spam'] = {$settings['ban_spam']};

// Ban websites with link passed in query string?
\$settings['ban_link_in_query'] = {$settings['ban_link_in_query']};

// Approve links manually?
\$settings['man_approval'] = {$settings['man_approval']};

// URL of the approve.php file on your server
\$settings['url_approval'] = '{$settings['url_approval']}';

// Use security question?
\$settings['question_use'] = {$settings['question_use']};

// Security question
\$settings['question_ask'] = '{$settings['question_ask']}';

// Answer to security question
\$settings['question_ans'] = '{$settings['question_ans']}';

// Use a simple security image?
\$settings['secimg_use'] = {$settings['secimg_use']};

// Use reCaptcha?
\$settings['recaptcha_use'] = {$settings['recaptcha_use']};

// reCaptcha site key
\$settings['recaptcha_site_key'] = '{$settings['recaptcha_site_key']}';

// reCaptcha secret key
\$settings['recaptcha_secret_key'] = '{$settings['recaptcha_secret_key']}';

// ==> MISC

// LinkMan User Agent
\$settings['user_agent'] = '{$settings['user_agent']}';

// Key used for automated link verification
\$settings['access_key'] = '{$settings['access_key']}';

// Name of the file where link URLs and other info is stored
\$settings['db_file'] = '{$settings['db_file']}';

// Name of the file where banned websites are stored
\$settings['ban_file'] = '{$settings['ban_file']}';

// Turn debug mode on?
\$settings['debug'] = {$settings['debug']};

// ==> INTERNAL

// A random string, used in generating password hashes
\$settings['salt_pass'] = '{$settings['salt_pass']}';

// A random string, used in combating SPAM
\$settings['salt_spam'] = '{$settings['salt_spam']}';

// A random string, used in generating temporary files
\$settings['salt_temp'] = '{$settings['salt_temp']}';

// LinkMan version
\$settings['version'] = '{$settings['version']}';

// Set error reporting options
if (\$settings['debug']) {
    error_reporting(E_ALL);
} else {
    error_reporting(0);
}", LOCK_EX) === false
        ) {
            $_SESSION['PJ_MESSAGES']['ERROR'] = 'Error writing to settings file, please try again later.';
        } else {
            pj_session_stop();
            $settings['INSTALL_OK'] = true;
        }
    }
}

// Set test session variable
$_SESSION['TEST'] = 1;

// Get header
include('../admin/admin_header.inc.php');

// Load main installation page
?>
    <div class="container">

    <div class="row">
        <div class="col-lg-12">
            <?php
            if ($settings['INSTALL_OK']) {
                ?>
                <div class="panel panel-success">
                    <div class="panel-heading">
                        <h3 class="panel-title">Installation successful</h3>
                    </div>
                    <div class="panel-body">

                        <h4>Next Steps:</h4>

                        &nbsp;

                        <ol>
                            <li><span style="color:red">Important: </span> For security reasons, delete the <b>install</b> folder from the server.<br/>&nbsp;</li>
                            <li><a href="../admin/index.php">Login to admin panel</a> to add new links, use various tools and manage settings.</li>
                        </ol>

                        <p>&nbsp;</p>

                    </div>
                </div>
                <?php
            } // END INSTALL OK
            else {
                ?>
                <div class="panel panel-default">
                    <div class="panel-heading">
                        <h3 class="panel-title">Installing PHP Link Manager</h3>
                    </div>
                    <div class="panel-body">

                        <?php pj_processMessages(); ?>

                        <p>&nbsp;</p>

                        <form method="POST" action="index.php" class="form-horizontal">

                            <div class="form-group">
                                <label class="col-lg-3 control-label">PHP Version:</label>
                                <?php
                                if (pj_test_error('PHP_VERSION', 1)) {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:red">
                                        <b><?php echo PHP_VERSION; ?></b><br/>This script requires PHP <?php echo REQUIRE_PHP_VERSION; ?> or newer. Running old PHP is insecure, ask your host to update it.
                                    </div>
                                    <?php
                                } else {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:green;font-weight:bold">
                                        OK
                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                            <div class="form-group">
                                <label class="col-lg-3 control-label">config/settings.php</label>
                                <?php
                                if (pj_test_error('SETTINGS', 1)) {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:red">
                                        <b>Not writable</b><br/>PHP needs permission to write to this file. On Linux servers CHMOD the file to 666 (rw-rw-rw-).
                                    </div>
                                    <?php
                                } else {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:green;font-weight:bold">
                                        OK
                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                            <div class="form-group">
                                <label class="col-lg-3 control-label">config/<?php echo pj_htmlspecialchars($settings['db_file']); ?></label>
                                <?php
                                if (pj_test_error('DATABASE')) {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:red">
                                        <b>File missing</b><br/>A required file is missing. Upload all LinkMan files to the server.
                                    </div>
                                    <?php
                                } elseif (pj_test_error('DATABASE', 1)) {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:red">
                                        <b>Not writable</b><br/>PHP needs permission to write to this file. On Linux servers CHMOD the file to 666 (rw-rw-rw-).
                                    </div>
                                    <?php
                                } else {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:green;font-weight:bold">
                                        OK
                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                            <div class="form-group">
                                <label class="col-lg-3 control-label">config/<?php echo pj_htmlspecialchars($settings['ban_file']); ?></label>
                                <?php
                                if (pj_test_error('BAN')) {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:red">
                                        <b>File missing</b><br/>A required file is missing. Upload all LinkMan files to the server.
                                    </div>
                                    <?php
                                } elseif (pj_test_error('BAN', 1)) {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:red">
                                        <b>Not writable</b><br/>PHP needs permission to write to this file. On Linux servers CHMOD the file to 666 (rw-rw-rw-).
                                    </div>
                                    <?php
                                } else {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:green;font-weight:bold">
                                        OK
                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                            <div class="form-group">
                                <label class="col-lg-3 control-label">/tmp</label>
                                <?php
                                if (pj_test_error('TMP')) {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:red">
                                        <b>Folder missing</b><br/>A required folder is missing. Upload all LinkMan files and folders to the server.
                                    </div>
                                    <?php
                                } elseif (pj_test_error('TMP', 1)) {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:red">
                                        <b>Not writable</b><br/>PHP needs permission to write to this folder. On Linux servers CHMOD the folder to 777 (rwxrwxrwx).
                                    </div>
                                    <?php
                                } else {
                                    ?>
                                    <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px;color:green;font-weight:bold">
                                        OK
                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                            <div class="form-group">
                                <label for="url" class="col-lg-3 control-label">Session test:</label>
                                <div class="col-lg-9" style="padding-top:7px;margin-bottom:10px">
                                    <?php echo isset($error_buffer['SESSION']) ? '<span style="color:red">' . $error_buffer['SESSION'] . '</span>' : ($settings['SESSION_OK'] ? '<span style="color:green"><b>OK</b></span>' : 'Started...'); ?>
                                </div>
                            </div>
                            <div class="form-group<?php echo isset($error_buffer['admin_pass']) ? ' has-error' : ''; ?>">
                                <label for="url" class="col-lg-3 control-label bold">Choose a password:</label>
                                <div class="col-lg-9">
                                    <input type="text" id="admin_pass" name="admin_pass" value="<?php echo stripslashes(pj_POST('admin_pass')); ?>" maxlength="255" class="form-control" placeholder="" autocomplete="off" style="width:300px">
                                    <p class="help-block"><?php echo isset($error_buffer['admin_pass']) ? $error_buffer['admin_pass'] : 'Choose a password you will use to login.'; ?></p>
                                </div>
                            </div>
                            <div class="form-group">
                                <div class="col-lg-offset-3 col-lg-9">
                                    <input type="hidden" name="action" value="save">
                                    <button type="submit" class="btn btn-primary"><i class="glyphicon glyphicon-floppy-disk"></i>&nbsp;<?php echo ($_SERVER['REQUEST_METHOD'] == 'POST') ? 'Save changes &amp; Test again' : 'Continue to step 2'; ?></button>
                                </div>
                            </div>
                        </form>

                        <p>&nbsp;</p>

                    </div>
                </div>
                <?php
            } // END install not OK
            ?>
        </div>
    </div>
<?php

// Get footer
include('../admin/admin_footer.inc.php');


////////////////////////////////////////////////////////////////////////////////
// FUNCTIONS
////////////////////////////////////////////////////////////////////////////////


function pj_test_error($type, $value = 0)
{
    global $error_buffer;

    if (isset($error_buffer[$type]) && $error_buffer[$type] == $value) {
        return true;
    }

    return false;
} // END pj_test_error()
