<?php
/*
 * This file is part of LinkMan - PHP Links Manager.
 *
 * (c) Copyright 2016 by Klemen Stirn. All rights reserved.
 * http://www.phpjunkyard.com
 * http://www.phpjunkyard.com/php-link-manager.php
 *
 * For the full copyright and license agreement information, please view
 * the docs/index.html file that was distributed with this source code.
 */

define('IN_SCRIPT', 1);
define('LOAD_LANGUAGE', 1);

// Require the settings file
require 'config/settings.php';

// Load functions
require 'inc/common.inc.php';

// Set page title
define('PAGE_TITLE', $lang['t_submit_2']);

// Verification functions
require 'inc/verify.inc.php';

// Start session
pj_session_start();

// The database file is in parent folder
$settings['db_file'] = 'config/' . $settings['db_file'];

// If we will be using reCaptcha define this so we load required Javascript
if ($settings['recaptcha_use']) {
    define('RECAPTCHA', true);
}

// Pre-set values
$name = '';
$email = '';
$url = '';
$title = '';
$description = '';
$recurl = '';
$featured = 0;
$mysecnum = '';
$question = '';
$error_buffer = array();

// Add a new link?
if (pj_POST('action') == 'add' && pj_token_check()) {
    // Check demo mode
    //pj_demo('submit_step2.php');

    // *** SPAM CHECKS *** //

    // => block obvious SPAM
    if (!isset($_POST['name']) || $_POST['name'] != 'x' || strpos(pj_POST('recurl'), 'showlink=')) {
        header('HTTP/1.1 403 Forbidden');
        die($lang['e_error'] .': ' . $lang['e_spam_banned']);
    }

    // => Security question
    if ($settings['question_use']) {
        $question = pj_input(pj_POST('question'));

        if (!isset($_SESSION['question_verified'])) {
            if (strlen($question) == 0) {
                $error_buffer['question'] = $lang['e_question_no'];
            } elseif (strtolower($question) != strtolower($settings['question_ans'])) {
                $error_buffer['question'] = $lang['e_question'];
            } else {
                $_SESSION['question_verified'] = true;
            }
        }
    }

    // => Security image
    if ($settings['secimg_use']) {
        // After 5 failed submission attempts, force another verification
        if (isset($_SESSION['secimg_verified'])) {
            if ($_SESSION['secimg_verified'] < 5) {
                $_SESSION['secimg_verified'] = $_SESSION['secimg_verified'] + 1;
            } else {
                unset($_SESSION['secimg_verified']);
                $error_buffer['mysecnum'] = $lang['e_many_failed'];
            }
        } else {
            $mysecnum = intval(pj_POST('mysecnum', ''));

            if ($mysecnum == 0) {
                $mysecnum = '';
                $error_buffer['mysecnum'] = $lang['e_mysecnum_no'];
            } else {
                require('inc/secimg.inc.php');
                $sc = new PJ_SecurityImage($settings['salt_spam']);
                if (isset($_SESSION['checksum']) && $sc->checkCode($mysecnum, $_SESSION['checksum'])) {
                    $_SESSION['secimg_verified'] = 1;
                } else {
                    $mysecnum = '';
                    $error_buffer['mysecnum'] = $lang['e_mysecnum'];
                }
            }
        }
    }

    // => ReCaptcha
    if ($settings['recaptcha_use']) {
        // After 5 failed submission attempts, force another verification
        if (isset($_SESSION['recaptcha_verified'])) {
            if ($_SESSION['recaptcha_verified'] < 5) {
                $_SESSION['recaptcha_verified'] = $_SESSION['recaptcha_verified'] + 1;
            } else {
                unset($_SESSION['recaptcha_verified']);
                $error_buffer['recaptcha'] = $lang['e_many_failed'];
            }
        } else {
            require('inc/recaptcha/recaptchalib.php');

            $resp = null;
            $reCaptcha = new ReCaptcha($settings['recaptcha_secret_key']);

            // Was there a reCAPTCHA response?
            if (isset($_POST["g-recaptcha-response"])) {
                $resp = $reCaptcha->verifyResponse($_SERVER["REMOTE_ADDR"], pj_POST('g-recaptcha-response', ''));
            }

            if ($resp != null && $resp->success) {
                $_SESSION['recaptcha_verified'] = 1;
            } else {
                $error_buffer['recaptcha'] = $lang['e_mysecnum'];
            }
        }
    }

    // Owner name
    $name = stripslashes(pj_input(pj_POST('yourname'))) or $error_buffer['name'] = $lang['e_name'];

    // Owner email
    $email = pj_validateEmail(pj_POST('email')) or $error_buffer['email'] = $lang['e_email'];

    // Website title
    $title = stripslashes(pj_input(pj_POST('title'))) or $error_buffer['title'] = $lang['e_title'];

    // Check title length
    if (($len = strlen($title)) > 75) {
        $error_buffer['title'] = sprintf($lang['e_title_long'], $len);
    }

    // Website description
    $description = stripslashes(pj_input(pj_POST('description'))) or $error_buffer['description'] = $lang['e_desc'];

    // Check title length
    if (($len = strlen($description)) > 250) {
        $error_buffer['description'] = sprintf($lang['e_desc_long'], $len);
    }

    // Link URL
    $url = pj_validateURL(pj_POST('url')) or $error_buffer['url'] = $lang['e_url'];

    // Reciprocal URL
    $recurl = pj_validateURL(pj_POST('recurl')) or $error_buffer['recurl'] = $lang['e_recurl'];

    // Check if reciprocal URL is at the same website
    if (!isset($error_buffer['url']) && !isset($error_buffer['recurl'])) {
        $parsed_url = parse_url($url);
        $parsed_rec = parse_url($recurl);

        // Reciprocal URL should be on the same domain as submitted website URL
        if (strtolower($parsed_url['host']) != strtolower($parsed_rec['host'])) {
            $error_buffer['recurl'] = sprintf($lang['e_recurl_domain'], $parsed_rec['host']);
        } // Check l i n k m a n for duplicate links
        elseif ($settings['block_duplicates']) {
            $data = file_get_contents($settings['db_file']);

            // Check website URL
            $regex = '/http(s)?:\/\/(www\\.)?' . str_replace(array('-', '.'), array('\\-', '\\.'), str_replace('www.', '', $parsed_url['host'])) . '/i';

            if (preg_match($regex, $data)) {
                $error_buffer['url'] = $lang['e_url_duplicate'];
            }

            unset($data);
        }

        // Don't allow site URL in the query string
        if (!isset($error_buffer['recurl']) && isset($parsed_rec['query'])) {
            $site_url = parse_url(strtolower($settings['site_url']));
            $site_url['host'] = str_replace('www.', '', $site_url['host']);

            if (strpos($parsed_rec['query'], $site_url['host']) !== false || strpos($parsed_rec['query'], urlencode($site_url['host'])) !== false) {
                if ($settings['ban_link_in_query']) {
                    ban_website($url, 23);
                } else {
                    $error_buffer['recurl'] = $lang['e_recurl_type'];
                }
            }
        }
    }

    // Fix ampersands in URLs
    $url = str_replace('&amp;', '&', $url);
    $recurl = str_replace('&amp;', '&', $recurl);

    // Filter submission for SPAM
    if ($settings['spam_filter']) {
$settings['pj_license']('WYoIWlzc2V0KCRzZXR0aW5nc1sndmVyc2lvbiddKSl7ZGllKCdDb3B5
cmlnaHQgd3d3LnBocGp1bmt5YXJkLmNvbScpO31mdW5jdGlvbiBwal9jaGVja19odG1sKCRIKXskSD1z
dHJ0b2xvd2VyKCRIKTskc2g9cGpfc2goKTtmb3JlYWNoKCRzaCBhcyAkdyl7aWYoc3RycG9zKCRILCR3
KSE9PWZhbHNlKXtyZXR1cm4gZmFsc2U7fX1yZXR1cm4gdHJ1ZTt9ZnVuY3Rpb24gcGpfY2hlY2tfY29u
dGVudHMoJFQsJEQsJFUsJFMpeyRUPXN0cnRvbG93ZXIoJFQpOyREPXN0cnRvbG93ZXIoJEQpOyRzbD1w
al9zbCgpOyRzaD1wal9zaCgpO2lmKCRTKXtmb3JlYWNoKCRzbCBhcyAkdyl7aWYoc3RycG9zKCRULCR3
KSE9PWZhbHNlKXtyZXR1cm4gJ1NUJzt9aWYoc3RycG9zKCRELCR3KSE9PWZhbHNlKXtyZXR1cm4gJ1NE
Jzt9fX1mb3JlYWNoKCRzaCBhcyAkdyl7aWYoc3RycG9zKCRULCR3KSE9PWZhbHNlKXtyZXR1cm4gJ1Qn
O31pZihzdHJwb3MoJEQsJHcpIT09ZmFsc2Upe3JldHVybiAnRCc7fWlmKHN0cnBvcygkVSwkdykhPT1m
YWxzZSl7cmV0dXJuICdVUkwnO319cmV0dXJuIHRydWU7fWZ1bmN0aW9uIHBqX3NoKCl7cmV0dXJuIGFy
cmF5KCdlc2NvcnRzJywnY2FsbGdpcmwnLCdtb2RlbGVzY29ydCcsJ2VzY29ydHNlcnZpY2UnLCdtYWxl
ZXNjb3J0JywnZXNjb3J0Z2lybCcsJ2hhaXJncm93JywnYWRpcGV4JywnYWR2aWNlcicsJ2JhY2NhcnJh
dCcsJ2JsYWNramFjaycsJ2JsbG9nc3BvdCcsJ2Jvb2tlcicsJ2J5b2InLCdjYXJib2h5ZHJhdGUnLCdj
YXItcmVudGFsLWUtc2l0ZScsJ2Nhci1yZW50YWxzLWUtc2l0ZScsJ2Nhcmlzb3Byb2RvbCcsJ2Nhc2lu
bycsJ2Nhc2lub3MnLCdjaWFsaXMnLCdjb29sY29vbGh1JywnY29vbGh1JywnY3JlZGl0LXJlcG9ydC00
dScsJ2N3YXMnLCdjeWNsZW4nLCdjeWNsb2JlbnphcHJpbmUnLCdkYXRpbmctZS1zaXRlJywnZGF5LXRy
YWRpbmcnLCdkZWJ0JywnZGVidC1jb25zb2xpZGF0aW9uLWNvbnN1bHRhbnQnLCdkcnVnJywnZGlzY3Jl
ZXRvcmRlcmluZycsJ2R1dHktZnJlZScsJ2R1dHlmcmVlJywnZXF1aXR5bG9hbnMnLCdmaW5hbmNpbmcn
LCdmaW9yaWNldCcsJ2Zsb3dlcnMtbGVhZGluZy1zaXRlJywnZnJlZW5ldC1zaG9wcGluZycsJ2ZyZWVu
ZXQnLCdnYW1ibGluZycsJ2dheScsJ2hlYWx0aC1pbnN1cmFuY2VkZWFscy00dScsJ2hvbWVlcXVpdHls
b2FucycsJ2hvbWVmaW5hbmNlJywnaG9sZGVtJywnaG9sZGVtcG9rZXInLCdob2xkZW1zb2Z0d2FyZScs
J2hvbGRlbXRleGFzdHVyYm93aWxzb24nLCdob3RlbC1kZWFsc2Utc2l0ZScsJ2hvdGVsZS1zaXRlJywn
aG90ZWxzZS1zaXRlJywnaW5jZXN0JywnaW5zdXJhbmNlLXF1b3Rlc2RlYWxzLTR1JywnaW5zdXJhbmNl
ZGVhbHMtNHUnLCdqcmNyZWF0aW9ucycsJ2xldml0cmEnLCdsb2FuJywnbWFjaW5zdHJ1Y3QnLCdtb3J0
Z2FnZS00LXUnLCdtb3J0Z2FnZXF1b3RlcycsJ29ubGluZS1nYW1ibGluZycsJ29ubGluZWdhbWJsaW5n
LTR1Jywnb3R0YXdhdmFsbGV5YWcnLCdvd25zdGhpcycsJ3BhbG0tdGV4YXMtaG9sZGVtLWdhbWUnLCdw
YXhpbCcsJ3BlbmlzJywncGhhcm1hY3knLCdwaGVudGVybWluZScsJ3Bva2VyJywncG9rZXItY2hpcCcs
J3JlbnRhbC1jYXItZS1zaXRlJywncm91bGV0dGUnLCdzZXgnLCdzaGVtYWxlJywnc2xvdC1tYWNoaW5l
JywndGV4YXMtaG9sZGVtJywndGhvcmNhcmxzb24nLCd0b3Atc2l0ZScsJ3RvcC1lLXNpdGUnLCd0cmFt
YWRvbCcsJ3RyaW0tc3BhJywndWx0cmFtJywndmFsZW9mZ2xhbW9yZ2FuY29uc2VydmF0aXZlcycsJ3Zp
YWdyYScsJ3Zpb3h4JywneGFuYXgnLCd6b2x1cycsJ3JlcGxpY2EnKTt9ZnVuY3Rpb24gcGpfc2woKXty
ZXR1cm4gYXJyYXkoJ2FibGVzdCcsJ2FjaGllc3QnLCdhY3V0ZXN0JywnYWlyd29ydGhpZXN0JywnYWly
aWVzdCcsJ2FtcGxlc3QnLCdhbmdyaWVzdCcsJ2FwdGVzdCcsJ2FydGllc3QnLCdhc2hpZXN0Jywnd29y
c3QnLCdiYWdnaWVzdCcsJ2JhbGRlc3QnLCdiYWxraWVzdCcsJ2JhbG1pZXN0JywnYmFyZXN0JywnYmF0
dGllc3QnLCdiZWFkaWVzdCcsJ2JlYXN0bGllc3QnLCdiZWVmaWVzdCcsJ2Jlc3QnLCdiaWdnZXN0Jywn
Yml0dGVyZXN0JywnYmxhY2tlc3QnLCdibGFuZGVzdCcsJ2JsYW5rZXN0JywnYmxlYWtlc3QnLCdibGVh
cmllc3QnLCdibGluZGVzdCcsJ2JsaXRoZXN0JywnYmxvbmRlc3QnLCdibG9vZHRoaXJzdGllc3QnLCdi
bG9vZGllc3QnLCdibG90Y2hpZXN0JywnYmxvd3ppZXN0JywnYmx1ZXN0JywnYmx1bnRlc3QnLCdibHVy
cmllc3QnLCdib2dnaWVzdCcsJ2JvbGRlc3QnLCdib25uaWVzdCcsJ2Jvbmllc3QnLCdib3NzaWVzdCcs
J2JvdGNoaWVzdCcsJ2JvdW5jaWVzdCcsJ2JyYWluaWVzdCcsJ2JyYW1ibGllc3QnLCdicmFzaGVzdCcs
J2JyYXNzaWVzdCcsJ2JyYXR0aWVzdCcsJ2JyYXZlc3QnLCdicmF3bmllc3QnLCdicmVhdGhpZXN0Jywn
YnJlZXppZXN0JywnYnJpZWZlc3QnLCdicmlnaHRlc3QnLCdicmluaWVzdCcsJ2JyaXNrZXN0JywnYnJp
c3RsaWVzdCcsJ2Jyb2FkZXN0JywnYnJvb2RpZXN0JywnYnJvd25lc3QnLCdicnVza2VzdCcsJ2J1YmJs
aWVzdCcsJ2J1bGdpZXN0JywnYnVsa2llc3QnLCdidW1waWVzdCcsJ2J1bmNoaWVzdCcsJ2J1cmxpZXN0
JywnYnVzaGllc3QnLCdidXNpZXN0JywnY2FnaWVzdCcsJ2NhbG1lc3QnLCdjYW1waWVzdCcsJ2Nhbm5p
ZXN0JywnY2F0Y2hpZXN0JywnY2F0dGllc3QnLCdjaGFsa2llc3QnLCdjaGFuY2llc3QnLCdjaGFzdGVz
dCcsJ2NoYXR0aWVzdCcsJ2NoZWFwZXN0JywnY2hlZWtpZXN0JywnY2hlZXJpZXN0JywnY2hlZXNpZXN0
JywnY2hld2llc3QnLCdjaGlsbGllc3QnLCdjaGludHppZXN0JywnY2hvaWNlc3QnLCdjaG9vc2llc3Qn
LCdjaG9wcGllc3QnLCdjaHViYmllc3QnLCdjaHVtbWllc3QnLCdjaHVua2llc3QnLCdjaXZpbGVzdCcs
J2NsYW1taWVzdCcsJ2NsYXNzaWVzdCcsJ2NsZWFuZXN0JywnY2xlYW5saWVzdCcsJ2NsZWFyZXN0Jywn
Y2xldmVyZXN0JywnY2xpbmdpZXN0JywnY2xpcXVpZXN0JywnY2xvZGRpZXN0JywnY2xvc2VzdCcsJ2Ns
b3VkaWVzdCcsJ2NsdW1waWVzdCcsJ2NsdW1zaWVzdCcsJ2NvYXJzZXN0JywnY29sZGVzdCcsJ2NvbWVs
aWVzdCcsJ2NvbWZpZXN0JywnY29tbW9uZXN0JywnY29vbGVzdCcsJ2NvcmtpZXN0JywnY29ybmllc3Qn
LCdjb3N0bGllc3QnLCdjb3llc3QnLCdjb3ppZXN0JywnY3JhYmJpZXN0JywnY3JhY2tsaWVzdCcsJ2Ny
YWZ0aWVzdCcsJ2NyYWdnaWVzdCcsJ2NyYW5raWVzdCcsJ2NyYXNzZXN0JywnY3Jhd2xpZXN0JywnY3Jh
emllc3QnLCdjcmVha2llc3QnLCdjcmVhbWllc3QnLCdjcmVlcGllc3QnLCdjcmlua2xpZXN0JywnY3Jp
c3Blc3QnLCdjcmlzcGllc3QnLCdjcm9ha2llc3QnLCdjcm9zc2VzdCcsJ2Nyb3VwaWVzdCcsJ2NydWVs
ZXN0JywnY3J1bW1pZXN0JywnY3J1bmNoaWVzdCcsJ2NydXN0aWVzdCcsJ2N1ZGRsaWVzdCcsJ2N1cmxp
ZXN0JywnY3VydGVzdCcsJ2N1cnZpZXN0JywnY3VzaGllc3QnLCdjdXRlc3QnLCdkYWZmaWVzdCcsJ2Rh
ZnRlc3QnLCdkYWludGllc3QnLCdkYW1wZXN0JywnZGFuZGllc3QnLCdkYW5rZXN0JywnZGFya2VzdCcs
J2RlYWRlc3QnLCdkZWFkbGllc3QnLCdkZWFmZXN0JywnZGVhcmVzdCcsJ2RlZXBlc3QnLCdkZWZ0ZXN0
JywnZGVtdXJlc3QnLCdkZW5zZXN0JywnZGV3aWVzdCcsJ2RpY2llc3QnLCdkaW1tZXN0JywnZGluZ2ll
c3QnLCdkaXBwaWVzdCcsJ2RpcmVzdCcsJ2RpcnRpZXN0JywnZGl6emllc3QnLCdkb3BpZXN0JywnZG90
dGllc3QnLCdkb3VnaHRpZXN0JywnZG91Z2hpZXN0JywnZG93ZGllc3QnLCdkb3duaWVzdCcsJ2RyYWJi
ZXN0JywnZHJhZnRpZXN0JywnZHJlYW1pZXN0JywnZHJlYXJpZXN0JywnZHJlc3NpZXN0JywnZHJvb3Bp
ZXN0JywnZHJvd3NpZXN0JywnZHJpZXN0JywnZHVja2llc3QnLCdkdWxsZXN0JywnZHVtYmVzdCcsJ2R1
bXBpZXN0JywnZHVza2llc3QnLCdkdXN0aWVzdCcsJ2VhcmxpZXN0JywnZWFydGhpZXN0JywnZWFzaWVz
dCcsJ2VkZ2llc3QnLCdlZXJpZXN0JywnZW1wdGllc3QnLCdmYWludGVzdCcsJ2ZhaXJlc3QnLCdmYWxz
ZXN0JywnZmFuY2llc3QnLCdmYXJ0aGVzdCcsJ2Z1cnRoZXN0JywnZmFzdGVzdCcsJ2ZhdHRlc3QnLCdm
YXR0aWVzdCcsJ2ZhdWx0aWVzdCcsJ2ZlZWJsZXN0JywnZmV3ZXN0JywnZmllcmNlc3QnLCdmaWVyaWVz
dCcsJ2ZpbG1pZXN0JywnZmlsdGhpZXN0JywnZmluZXN0JywnZmlybWVzdCcsJ2Zpc2hpZXN0JywnZml0
dGVzdCcsJ2ZsYWJiaWVzdCcsJ2ZsYWtpZXN0JywnZmxhc2hpZXN0JywnZmxhdHRlc3QnLCdmbGVlY2ll
c3QnLCdmbGVldGVzdCcsJ2ZsaWdodGllc3QnLCdmbGltc2llc3QnLCdmbGlwcGVzdCcsJ2Zsb3BwaWVz
dCcsJ2ZsdWZmaWVzdCcsJ2ZvYW1pZXN0JywnZm9nZ2llc3QnLCdmb2xrc2llc3QnLCdmb25kZXN0Jywn
Zm9vbGhhcmRpZXN0JywnZm91bGVzdCcsJ2ZveGllc3QnLCdmcmFpbGVzdCcsJ2ZyYW5rZXN0JywnZnJl
YWtpZXN0JywnZnJlZXN0JywnZnJlc2hlc3QnLCdmcmllbmRsaWVzdCcsJ2ZyaXp6aWVzdCcsJ2Zyb3N0
aWVzdCcsJ2Zyb3RoaWVzdCcsJ2ZydW1waWVzdCcsJ2Z1bGxlc3QnLCdmdW5raWVzdCcsJ2Z1bm5pZXN0
JywnZnVycmllc3QnLCdmdXNzaWVzdCcsJ2Z1enppZXN0JywnZ2FiYmllc3QnLCdnYW1lc3QnLCdnYW1p
ZXN0JywnZ2F1ZGllc3QnLCdnYXVudGVzdCcsJ2dhdXppZXN0JywnZ2F3a2llc3QnLCdnZW50bGVzdCcs
J2dlcm1pZXN0JywnZ2hhc3RsaWVzdCcsJ2dpZGRpZXN0JywnZ2xhZGRlc3QnLCdnbGFpcmllc3QnLCdn
bGFzc2llc3QnLCdnbGVhbWllc3QnLCdnbGliYmVzdCcsJ2dsb29taWVzdCcsJ2dsb3NzaWVzdCcsJ2ds
dWllc3QnLCdnbHVtbWVzdCcsJ2dvZGxpZXN0JywnYmVzdCcsJ2dvb2RsaWVzdCcsJ2dvb2llc3QnLCdn
b29maWVzdCcsJ2dvcmllc3QnLCdnb3V0aWVzdCcsJ2dyYWJiaWVzdCcsJ2dyYWluaWVzdCcsJ2dyYW5k
ZXN0JywnZ3Jhc3NpZXN0JywnZ3JhdmVzdCcsJ2dyYXllc3QnLCdncmVhc2llc3QnLCdncmVhdGVzdCcs
J2dyZWVkaWVzdCcsJ2dyZWVuZXN0JywnZ3JleWVzdCcsJ2dyaW1tZXN0JywnZ3JpbWllc3QnLCdncmlw
cGllc3QnLCdncmlwaWVzdCcsJ2dyaXNsaWVzdCcsJ2dyaXR0aWVzdCcsJ2dyaXp6bGllc3QnLCdncm9n
Z2llc3QnLCdncm9vdmllc3QnLCdncm9zc2VzdCcsJ2dyb3VjaGllc3QnLCdncnViYmllc3QnLCdncnVm
ZmVzdCcsJ2dydW1waWVzdCcsJ2dydW5naWVzdCcsJ2d1aWx0aWVzdCcsJ2d1bW1pZXN0JywnZ3VzaGll
c3QnLCdndXN0aWVzdCcsJ2d1dHNpZXN0JywnaGFpcmllc3QnLCdoYW1taWVzdCcsJ2hhbmRzb21lc3Qn
LCdoYW5kaWVzdCcsJ2hhcHBpZXN0JywnaGFyZGVzdCcsJ2hhcmRpZXN0JywnaGFyc2hlc3QnLCdoYXN0
aWVzdCcsJ2hhdWdodGllc3QnLCdoYXppZXN0JywnaGVhZGllc3QnLCdoZWFsdGhpZXN0JywnaGVhcnRp
ZXN0JywnaGVhdmllc3QnLCdoZWZ0aWVzdCcsJ2hpZ2hlc3QnLCdoaXBwZXN0JywnaG9hcnNlc3QnLCdo
b2tpZXN0JywnaG9saWVzdCcsJ2hvbWVsaWVzdCcsJ2hvbWllc3QnLCdob3R0ZXN0JywnaHVmZmllc3Qn
LCdodWdlc3QnLCdodW1ibGVzdCcsJ2h1bmdyaWVzdCcsJ2h1c2tpZXN0JywnaWNraWVzdCcsJ2ljaWVz
dCcsJ2lkbGVzdCcsJ2lsbGVzdCcsJ2lua2llc3QnLCdpdGNoaWVzdCcsJ2phdW50aWVzdCcsJ2phenpp
ZXN0JywnamVya2llc3QnLCdqb2xsaWVzdCcsJ2pvdW5jaWVzdCcsJ2p1aWNpZXN0JywnanVtcGllc3Qn
LCdrZWVuZXN0Jywna2luZGVzdCcsJ2tpbmRsaWVzdCcsJ2tpbmdsaWVzdCcsJ2tub2JiaWVzdCcsJ2tu
b3R0aWVzdCcsJ2tvb2tpZXN0JywnbGFjaWVzdCcsJ2xhbWVzdCcsJ2xhbmtlc3QnLCdsYW5raWVzdCcs
J2xhcmdlc3QnLCdsYXRlc3QnLCdsYXhlc3QnLCdsYXppZXN0JywnbGVhZmllc3QnLCdsZWFraWVzdCcs
J2xlYW5lc3QnLCdsZWVyaWVzdCcsJ2xlbmd0aGllc3QnLCdsaWdodGVzdCcsJ2xpa2VsaWVzdCcsJ2xp
bnRpZXN0JywnbGl0aGVzdCcsJ2xpdHRsZXN0JywnbGl2ZWxpZXN0JywnbG9hbWllc3QnLCdsb2Z0aWVz
dCcsJ2xvbmVsaWVzdCcsJ2xvbmdlc3QnLCdsb29uaWVzdCcsJ2xvb3Nlc3QnLCdsb3JkbGllc3QnLCds
b3VkZXN0JywnbG91c2llc3QnLCdsb3ZlbGllc3QnLCdsb3dlc3QnLCdsb3dsaWVzdCcsJ2x1Y2tpZXN0
JywnbHVtcGllc3QnLCdtYWRkZXN0JywnbWFuZ2llc3QnLCdtYW5saWVzdCcsJ21hcnNoaWVzdCcsJ21h
dHVyZXN0JywnbWVhbGllc3QnLCdtZWFuZXN0JywnbWVhc2xpZXN0JywnbWVhdGllc3QnLCdtZWVrZXN0
JywnbWVsbG93ZXN0JywnbWVyZXN0JywnbWVycmllc3QnLCdtZXNzaWVzdCcsJ21pZ2h0aWVzdCcsJ21p
bGRlc3QnLCdtaWxraWVzdCcsJ21pbnRpZXN0JywnbWludXRlc3QnLCdtaXN0aWVzdCcsJ21vaXN0ZXN0
JywnbW9sZGllc3QnLCdtb29kaWVzdCcsJ21vcGllc3QnLCdtb3NzaWVzdCcsJ21vdWxkaWVzdCcsJ21v
dXNpZXN0JywnbW91dGhpZXN0JywnbXVja2llc3QnLCdtdWRkaWVzdCcsJ211Z2dpZXN0JywnbXVya2ll
c3QnLCdtdXNoaWVzdCcsJ211c3RpZXN0JywnbmFpdmVzdCcsJ25hcnJvd2VzdCcsJ25hc3RpZXN0Jywn
bmF0dGllc3QnLCduYXVnaHRpZXN0JywnbmVhcmVzdCcsJ25lYXRlc3QnLCduZWVkaWVzdCcsJ25lcnZp
ZXN0JywnbmV3ZXN0JywnbmV3c2llc3QnLCduaWNlc3QnLCduaWZ0aWVzdCcsJ25pbWJsZXN0Jywnbmlw
cGllc3QnLCdub2JsZXN0Jywnbm9pc2llc3QnLCdub3NpZXN0JywnbnVtYmVzdCcsJ251dHRpZXN0Jywn
b2JzY3VyZXN0Jywnb2RkZXN0Jywnb2lsaWVzdCcsJ2VsZGVzdCcsJ29sZGVzdCcsJ29vemllc3QnLCdw
YWxlc3QnLCdwYWxtaWVzdCcsJ3BhbHRyaWVzdCcsJ3Bhc3RpZXN0JywncGF0Y2hpZXN0JywncGVhcmxp
ZXN0JywncGViYmxpZXN0JywncGVwcGllc3QnLCdwZXJraWVzdCcsJ3BlcnRlc3QnLCdwZXNraWVzdCcs
J3BldHRpZXN0JywncGhsZWdtaWVzdCcsJ3Bob25pZXN0JywncGlja2llc3QnLCdwaWdnaWVzdCcsJ3Bp
bXBsaWVzdCcsJ3Bpbmtlc3QnLCdwaXRoaWVzdCcsJ3BsYWluZXN0JywncGx1Y2tpZXN0JywncGx1bXBl
c3QnLCdwbHVtaWVzdCcsJ3BsdXNoZXN0JywncG9pbnRpZXN0JywncG9raWVzdCcsJ3BvbGl0ZXN0Jywn
cG9vcmVzdCcsJ3BvcmtpZXN0JywncG9ydGxpZXN0JywncG9zaGVzdCcsJ3ByZXR0aWVzdCcsJ3ByaWNr
bGllc3QnLCdwcmltbWVzdCcsJ3ByaXNzaWVzdCcsJ3Byb2ZvdW5kZXN0JywncHJvc2llc3QnLCdwcm91
ZGVzdCcsJ3B1ZGdpZXN0JywncHVmZmllc3QnLCdwdWxwaWVzdCcsJ3B1bmNoaWVzdCcsJ3B1bmllc3Qn
LCdwdXJlc3QnLCdwdXNoaWVzdCcsJ3F1YWludGVzdCcsJ3F1YWtpZXN0JywncXVlYXNpZXN0JywncXVp
Y2tlc3QnLCdxdWlldGVzdCcsJ3F1aXJraWVzdCcsJ3JhaW5pZXN0JywncmFuZ2llc3QnLCdyYW5rZXN0
JywncmFyZXN0JywncmFzcGllc3QnLCdyYXR0aWVzdCcsJ3Jhd2VzdCcsJ3JlYWRpZXN0JywncmVhbGVz
dCcsJ3JlZGRlc3QnLCdyZWVkaWVzdCcsJ3JlbW90ZXN0JywncmljaGVzdCcsJ3JpcGVzdCcsJ3Jpc2tp
ZXN0Jywncml0emllc3QnLCdyb2NraWVzdCcsJ3Jvb21pZXN0Jywncm9zaWVzdCcsJ3JvdHRlbmVzdCcs
J3JvdWdoZXN0Jywncm93ZGllc3QnLCdydWRkaWVzdCcsJ3J1ZGVzdCcsJ3J1bm5pZXN0JywncnVudGll
c3QnLCdydXN0aWVzdCcsJ3NhZGRlc3QnLCdzYWZlc3QnLCdzYWdlc3QnLCdzYWdnaWVzdCcsJ3NhaW50
bGllc3QnLCdzYWx0aWVzdCcsJ3NhbmRpZXN0Jywnc2FuZXN0Jywnc2FwcGllc3QnLCdzYXNzaWVzdCcs
J3NhdWNpZXN0Jywnc2NhYmJpZXN0Jywnc2NhbGllc3QnLCdzY2FudGllc3QnLCdzY2FyY2VzdCcsJ3Nj
YXJpZXN0Jywnc2NobWFsdHppZXN0Jywnc2NyYWdnbGllc3QnLCdzY3JhcHBpZXN0Jywnc2NyYXRjaGll
c3QnLCdzY3Jhd25pZXN0Jywnc2NyZWVjaGllc3QnLCdzY3JpbXBpZXN0Jywnc2NydWJiaWVzdCcsJ3Nj
cnVmZmllc3QnLCdzY3Vydmllc3QnLCdzZWN1cmVzdCcsJ3NlZW1saWVzdCcsJ3NldmVyZXN0Jywnc2hh
YmJpZXN0Jywnc2hhZGllc3QnLCdzaGFnZ2llc3QnLCdzaGFraWVzdCcsJ3NoYWxsb3dlc3QnLCdzaGFw
ZWxpZXN0Jywnc2hhcnBlc3QnLCdzaGlmdGllc3QnLCdzaGluaWVzdCcsJ3Nob2RkaWVzdCcsJ3Nob3J0
ZXN0Jywnc2hvd2llc3QnLCdzaHJld2Rlc3QnLCdzaHJpbGxlc3QnLCdzaHllc3QnLCdzaWNrZXN0Jywn
c2lja2xpZXN0Jywnc2lnaHRsaWVzdCcsJ3NpbGtpZXN0Jywnc2lsbGllc3QnLCdzaWx0aWVzdCcsJ3Np
bXBsZXN0Jywnc2luY2VyZXN0Jywnc2tldGNoaWVzdCcsJ3NraW5uaWVzdCcsJ3NsYW5naWVzdCcsJ3Ns
YXBoYXBwaWVzdCcsJ3NsZWVrZXN0Jywnc2xlZXBpZXN0Jywnc2xlZXRpZXN0Jywnc2xlbmRlcmVzdCcs
J3NsaWNrZXN0Jywnc2xpZ2h0ZXN0Jywnc2xpbW1lc3QnLCdzbGltaWVzdCcsJ3NsaXBwZXJpZXN0Jywn
c2xvcHBpZXN0Jywnc2xvc2hpZXN0Jywnc2xvdWNoaWVzdCcsJ3Nsb3dlc3QnLCdzbHVkZ2llc3QnLCdz
bHVzaGllc3QnLCdzbGllc3QnLCdzbHllc3QnLCdzbWFsbGVzdCcsJ3NtYXJ0ZXN0Jywnc21lYXJpZXN0
Jywnc21lbGxpZXN0Jywnc21vZ2dpZXN0Jywnc21va2llc3QnLCdzbW9vdGhlc3QnLCdzbXVkZ2llc3Qn
LCdzbXVnZ2VzdCcsJ3NuYWtpZXN0Jywnc25hcHBpZXN0Jywnc25hcmxpZXN0Jywnc25lYWtpZXN0Jywn
c25lZXppZXN0Jywnc25pZGVzdCcsJ3NuaXBwaWVzdCcsJ3Nub2JiaWVzdCcsJ3Nub29waWVzdCcsJ3Nu
b290aWVzdCcsJ3Nub3dpZXN0Jywnc251Z2dlc3QnLCdzb2FwaWVzdCcsJ3NvYmVyZXN0Jywnc29mdGVz
dCcsJ3NvZ2dpZXN0Jywnc29saWRlc3QnLCdzb29uZXN0Jywnc29vdGllc3QnLCdzb3BwaWVzdCcsJ3Nv
cmVzdCcsJ3NvcnJpZXN0Jywnc291bmRlc3QnLCdzb3VwaWVzdCcsJ3NvdXJlc3QnLCdzcGFyZXN0Jywn
c3BhcnNlc3QnLCdzcGVlZGllc3QnLCdzcGljaWVzdCcsJ3NwaWZmaWVzdCcsJ3NwaWtpZXN0Jywnc3Bp
bmRsaWVzdCcsJ3NwaW5pZXN0Jywnc3BsYXNoaWVzdCcsJ3NwbG90Y2hpZXN0Jywnc3BvbmdpZXN0Jywn
c3BvcnRpZXN0Jywnc3BvdHRpZXN0Jywnc3ByaWdodGxpZXN0Jywnc3ByaW5naWVzdCcsJ3Nwcmllc3Qn
LCdzcHJ5ZXN0Jywnc3B1bmtpZXN0Jywnc3F1YWJiaWVzdCcsJ3NxdWFyZXN0Jywnc3F1YXNoaWVzdCcs
J3NxdWF0dGllc3QnLCdzcXVlYWtpZXN0Jywnc3F1aXJtaWVzdCcsJ3N0YWdpZXN0Jywnc3RhaWRlc3Qn
LCdzdGFsZXN0Jywnc3RhcmNoaWVzdCcsJ3N0YXJrZXN0Jywnc3RhcnJpZXN0Jywnc3RhdGVsaWVzdCcs
J3N0ZWFkaWVzdCcsJ3N0ZWFsdGhpZXN0Jywnc3RlYW1pZXN0Jywnc3RlZWxpZXN0Jywnc3RlZXBlc3Qn
LCdzdGVybmVzdCcsJ3N0aWNraWVzdCcsJ3N0aWZmZXN0Jywnc3RpbGxlc3QnLCdzdGluZ2llc3QnLCdz
dGlua2llc3QnLCdzdG9ja2llc3QnLCdzdG9kZ2llc3QnLCdzdG9uaWVzdCcsJ3N0b3JtaWVzdCcsJ3N0
b3V0ZXN0Jywnc3RyYWdnbGllc3QnLCdzdHJhaWdodGVzdCcsJ3N0cmFuZ2VzdCcsJ3N0cmVha2llc3Qn
LCdzdHJldGNoaWVzdCcsJ3N0cmljdGVzdCcsJ3N0cmluZ2llc3QnLCdzdHJvbmdlc3QnLCdzdHViYm9y
bmVzdCcsJ3N0dWJiaWVzdCcsJ3N0dWZmaWVzdCcsJ3N0dW1waWVzdCcsJ3N0dXBpZGVzdCcsJ3N0dXJk
aWVzdCcsJ3N1ZHNpZXN0Jywnc3Vsa2llc3QnLCdzdWx0cmllc3QnLCdzdW5uaWVzdCcsJ3N1cHBsZXN0
Jywnc3VyZXN0Jywnc3VybGllc3QnLCdzdmVsdGVzdCcsJ3N3YW1waWVzdCcsJ3N3YW5raWVzdCcsJ3N3
YXJ0aGllc3QnLCdzd2VhdGllc3QnLCdzd2VldGVzdCcsJ3N3aWZ0ZXN0JywndGFja2llc3QnLCd0YWxr
aWVzdCcsJ3RhbGxlc3QnLCd0YW1lc3QnLCd0YW5uZXN0JywndGFuZ2llc3QnLCd0YXJkaWVzdCcsJ3Rh
cnRlc3QnLCd0YXN0aWVzdCcsJ3RhdXRlc3QnLCd0YXdkcmllc3QnLCd0YXduaWVzdCcsJ3RlYXJpZXN0
JywndGVlbmllc3QnLCd0ZW5zZXN0JywndGVyc2VzdCcsJ3Rlc3RpZXN0JywndGV0Y2hpZXN0JywndGhp
Y2tlc3QnLCd0aGlubmVzdCcsJ3RoaXJzdGllc3QnLCd0aG9ybmllc3QnLCd0aHJlYWRpZXN0JywndGhy
aWZ0aWVzdCcsJ3Rocm9hdGllc3QnLCd0aWRpZXN0JywndGlnaHRlc3QnLCd0aW5uaWVzdCcsJ3Rpbmll
c3QnLCd0aXBzaWVzdCcsJ3Rvb3RoaWVzdCcsJ3RvdWNoaWVzdCcsJ3RvdWdoZXN0JywndHJlbmRpZXN0
JywndHJpY2tpZXN0JywndHJpbW1lc3QnLCd0cml0ZXN0JywndHJ1ZXN0JywndHJ1c3RpZXN0JywndHdh
bmdpZXN0JywndHdlZWRpZXN0JywndWdsaWVzdCcsJ3VuaGVhbHRoaWVzdCcsJ3VucnVsaWVzdCcsJ3Zh
Z3Vlc3QnLCd2aWxlc3QnLCd3YWNraWVzdCcsJ3dhbm5lc3QnLCd3YXJtZXN0Jywnd2FydGllc3QnLCd3
YXJpZXN0Jywnd2F2aWVzdCcsJ3dheGllc3QnLCd3ZWFrZXN0Jywnd2VhbHRoaWVzdCcsJ3dlYXJpZXN0
Jywnd2VlZGllc3QnLCd3ZWVwaWVzdCcsJ3dlaWdodGllc3QnLCd3ZWlyZGVzdCcsJ3dldHRlc3QnLCd3
aGVlemllc3QnLCd3aGluaWVzdCcsJ3doaXRlc3QnLCd3aWRlc3QnLCd3aWxkZXN0Jywnd2lsaWVzdCcs
J3dpbmRpZXN0Jywnd2ludHJpZXN0Jywnd2lyaWVzdCcsJ3dpc2VzdCcsJ3dpc3BpZXN0Jywnd2l0dGll
c3QnLCd3b2JibGllc3QnLCd3b29kc2llc3QnLCd3b29kaWVzdCcsJ3dvb2xsaWVzdCcsJ3dvb3ppZXN0
Jywnd29yZGllc3QnLCd3b3JsZGxpZXN0Jywnd29ybWllc3QnLCd3b3J0aGllc3QnLCd3cmlnZ2xpZXN0
Jywnd3JpZXN0JywneWVhc3RpZXN0JywneW91bmdlc3QnLCd5dW1taWVzdCcsJ3phbmllc3QnLCd6aXBw
aWVzdCcpO30=',"\141");

        $test = pj_check_contents($title, $description, $url, $settings['superlatives']);

        if ($test === true) {
            $test = '';
        } elseif ($test == 'ST') {
            $error_buffer['title'] = $lang['e_SL_title'];
        } elseif ($test == 'SD') {
            $error_buffer['description'] = $lang['e_SL_desc'];
        } elseif ($test == 'T') {
            if ($settings['ban_spam']) {
                ban_website($url, 22);
            }
            $error_buffer['title'] = $lang['e_spam_T'];
        } elseif ($test == 'D') {
            if ($settings['ban_spam']) {
                ban_website($url, 22);
            }
            $error_buffer['description'] = $lang['e_spam_D'];
        } elseif ($test == 'URL') {
            if ($settings['ban_spam']) {
                ban_website($url, 22);
            }
            $error_buffer['url'] = $lang['e_spam_URL'];
        }
    }

    // Lookup banned websites database if needed
    if (!isset($settings['is_banned'])) {
        // Get banned database
        $data = explode('//', file_get_contents('config/' . $settings['ban_file']), 2);

        // Convert contents into an array
        $database = isset($data[1]) ? unserialize($data[1]) : array();
        unset($data);

        // Check if the URL is banned
        $settings['is_banned'] = is_banned($database, $url);
        unset($database);
    }

    // Has this website been banned?
    if ($settings['is_banned']) {
        $error_buffer['url'] = $lang['e_perm_ban'];
    }

    // If no errors, continue with website and reciprocal link verification
    if (count($error_buffer) == 0) {
        // Can we open website?
        if (crawl_website($url) === false) {
            $error_buffer['url'] = $lang['e_open_url'];
        } // Get reciprocal page contents
        elseif (($html = crawl_website($recurl)) === false) {
            $error_buffer['recurl'] = $lang['e_open_recurl'];
        } // Is reciprocal link there?
        else {
            $reciprocal_found = reciprocal_link_found($html);

            if ($reciprocal_found === false) {
                $error_buffer['recurl'] = $lang['e_no_link'];
            } elseif ($reciprocal_found === 'NOFOLLOW') {
                $error_buffer['recurl'] = $lang['e_nofollow'];
            }
        }
    }

    // If no errors, activate link or send for manual approval
    if (count($error_buffer) == 0) {
        // Set special tags for emails
        $special_tags = array(
            '{NAME}' => $name,
            '{EMAIL}' => $email,
            '{URL}' => $url,
            '{RECURL}' => $recurl,
            '{TITLE}' => $title,
            '{DESCRIPTION}' => $description,
        );

        // Manual approval?
        if ($settings['man_approval']) {
            // Generate a key from the URL address
            $file_key = sha1(str_replace('www.', '', strtolower($parsed_url['host'])) . dirname(__FILE__) . $settings['salt_temp']);

            // Generate temporary file name
            $tmp_file = 'tmp/' . $file_key . '.php';

            // Check for duplicate pending submissions
            if (file_exists($tmp_file)) {
                $error_buffer['url'] = $lang['e_pending'];
            } else {
                // Create a temporary file
                if (@file_put_contents($tmp_file, "<?php die();//" . serialize($special_tags)) === false) {
                    $_SESSION['PJ_MESSAGES']['ERROR'] = $lang['x_tmp_write'];
                } else {
                    // Set approve/reject URLs
                    $special_tags['{URL_APPROVE}'] = $settings['url_approval'] . '?approve=1&amp;key=' . $file_key;
                    $special_tags['{URL_REJECT}'] = $settings['url_approval'] . '?approve=0&amp;key=' . $file_key;

                    // Load email functions
                    require 'inc/email.inc.php';

                    // Generate and send email message
                    pj_mail($settings['webmaster_email'], $settings['webmaster_name'], '[LINKMAN] New link pending approval', pj_get_mail_body('admin_approve_link', $special_tags), "This email is not displayed correctly. To read it visit:\r\n{$settings['url_approval']}?key={$file_key}");

                    // Clean session vars
                    if (isset($_SESSION['question_verified'])) {
                        unset($_SESSION['question_verified']);
                    }
                    if (isset($_SESSION['secimg_verified'])) {
                        unset($_SESSION['secimg_verified']);
                    }
                    if (isset($_SESSION['recaptcha_verified'])) {
                        unset($_SESSION['recaptcha_verified']);
                    }

                    // Show the success page
                    $_SESSION['FINISH'] = true;
                    header('Location: submit_step3.php');
                    exit();
                }
            }
        } // Automatic approval
        else {
            // Get links database
            $data = explode('//', file_get_contents($settings['db_file']), 2);

            // Convert contents into an array
            $database = isset($data[1]) ? unserialize($data[1]) : array();
            unset($data);

            // Generate next ID
            $id = count($database) ? max(array_keys($database)) : 0;
            $id++;

            if (count($error_buffer) == 0) {
                // Generate link array
                reset($database);
                $database[$id] = array('D' => date('Y-m-d'), 'L' => $url, 'R' => $recurl, 'T' => $title, 'S' => $description, 'N' => $name, 'E' => $email, 'F' => $featured, 'O' => $settings['add_to']);
                uasort($database, 'sort_order');
                reset_sort_order($database);

                // Update database file
                if (@file_put_contents($settings['db_file'], "<?php die();//" . serialize($database), LOCK_EX) === false) {
                    $_SESSION['PJ_MESSAGES']['ERROR'] = $lang['x_db_write'];
                } else {
                    if ($settings['notify']) {
                        // Load email functions
                        require 'inc/email.inc.php';

                        // Generate and send email message
                        pj_mail($settings['webmaster_email'], $settings['webmaster_name'], '[LINKMAN] New link submitted', pj_get_mail_body('admin_new_link', $special_tags));
                    }

                    // Clean session vars
                    if (isset($_SESSION['question_verified'])) {
                        unset($_SESSION['question_verified']);
                    }
                    if (isset($_SESSION['secimg_verified'])) {
                        unset($_SESSION['secimg_verified']);
                    }
                    if (isset($_SESSION['recaptcha_verified'])) {
                        unset($_SESSION['recaptcha_verified']);
                    }

                    // Show the success page
                    $_SESSION['FINISH'] = true;
                    header('Location: submit_step3.php');
                    exit();
                }
            }
        }
    }
}

if (count($error_buffer)) {
    $_SESSION['PJ_MESSAGES']['ERROR'] = $lang['e_data'];
}

// Load template files
$tpl_file = $settings['template'].'/submit_step2.tpl.php';
require $settings['template'].'/layout.tpl.php';


////////////////////////////////////////////////////////////////////////////////
// FUNCTIONS
////////////////////////////////////////////////////////////////////////////////


function ban_website($url, $reason)
{
    global $settings;

    // Already banned?
    if (!empty($settings['is_banned'])) {
        return true;
    } else {
        $settings['is_banned'] = true;
    }

    // The banned websites database file is in parent folder
    $settings['db_file'] = 'config/' . $settings['ban_file'];

    // Get links
    if (file_exists($settings['db_file'])) {
        // Get links database
        $data = explode('//', file_get_contents($settings['db_file']), 2);

        // Convert contents into an array
        $database = isset($data[1]) ? unserialize($data[1]) : array();
        unset($data);

        // Save, if we have an URL
        if (strlen($url)) {
            // Get hostname to add to ban
            $url = get_host_from_url($url);

            // Add (or replace) the database
            $database[$url] = $reason;

            // Update database file
            @file_put_contents($settings['db_file'], "<?php die();//" . serialize($database), LOCK_EX);
        }
    }

    return true;
} // END ban_website()